from typing import List

from .. import Provider as CompanyProvider


def regon_checksum(digits: List[int]) -> int:
    """
    Calculates and returns a control digit for given list of digits basing on REGON standard.
    """
    weights_for_check_digit = [8, 9, 2, 3, 4, 5, 6, 7]
    check_digit = 0

    for i in range(0, 8):
        check_digit += weights_for_check_digit[i] * digits[i]

    check_digit %= 11

    if check_digit == 10:
        check_digit = 0

    return check_digit


def local_regon_checksum(digits: List[int]) -> int:
    """
    Calculates and returns a control digit for given list of digits basing on local REGON standard.
    """
    weights_for_check_digit = [2, 4, 8, 5, 0, 9, 7, 3, 6, 1, 2, 4, 8]
    check_digit = 0

    for i in range(0, 13):
        check_digit += weights_for_check_digit[i] * digits[i]

    check_digit %= 11

    if check_digit == 10:
        check_digit = 0

    return check_digit


def company_vat_checksum(digits: List[int]) -> int:
    """
    Calculates and returns a control digit for given list of digits basing on NIP standard.
    """
    weights_for_check_digit = [6, 5, 7, 2, 3, 4, 5, 6, 7]
    check_digit = 0

    for i in range(0, 9):
        check_digit += weights_for_check_digit[i] * digits[i]

    check_digit %= 11

    return check_digit


class Provider(CompanyProvider):
    formats = (
        "{{last_name}} {{company_suffix}}",
        "{{last_name}}-{{last_name}} {{company_suffix}}",
        "{{company_prefix}} {{last_name}}",
        "{{company_prefix}} {{last_name}} {{company_suffix}}",
        "{{company_prefix}} {{last_name}}-{{last_name}} {{company_suffix}}",
    )

    company_prefixes = (
        "Grupa",
        "Spółdzielnia",
        "Stowarzyszenie",
        "Fundacja",
        "PPUH",
        "FPUH",
        "Gabinety",
    )

    company_suffixes = (
        "Sp. z o.o.",
        "S.A.",
        "Sp. z o.o. Sp.k.",
        "Sp.j.",
        "s.c.",
        "Sp.k.",
        "i syn s.c.",
    )

    def company_prefix(self) -> str:
        """
        :example 'Grupa'
        """
        return self.random_element(self.company_prefixes)

    def regon(self) -> str:
        """
        Returns 9 character Polish National Business Registry Number,
        Polish: Rejestr Gospodarki Narodowej - REGON.

        https://pl.wikipedia.org/wiki/REGON
        """
        voivodeship_number = self.random_int(0, 49) * 2 + 1
        regon_digits = [int(voivodeship_number / 10), voivodeship_number % 10]

        for _ in range(6):
            regon_digits.append(self.random_digit())

        regon_digits.append(regon_checksum(regon_digits))

        return "".join(str(digit) for digit in regon_digits)

    def local_regon(self) -> str:
        """
        Returns 14 character Polish National Business Registry Number,
        local entity number.

        https://pl.wikipedia.org/wiki/REGON
        """
        regon_digits = [int(digit) for digit in list(self.regon())]

        for _ in range(4):
            regon_digits.append(self.random_digit())

        regon_digits.append(local_regon_checksum(regon_digits))

        return "".join(str(digit) for digit in regon_digits)

    def company_vat(self) -> str:
        """
        Returns 10 character tax identification number,
        Polish: Numer identyfikacji podatkowej.

        https://pl.wikipedia.org/wiki/NIP
        """
        vat_digits = []

        for _ in range(3):
            vat_digits.append(self.random_digit_not_null())

        for _ in range(6):
            vat_digits.append(self.random_digit())

        check_digit = company_vat_checksum(vat_digits)

        # in this case we must generate a tax number again, because check_digit
        # cannot be 10
        if check_digit == 10:
            return self.company_vat()

        vat_digits.append(check_digit)

        return "".join(str(digit) for digit in vat_digits)



from collections import OrderedDict
from functools import cached_property
from typing import Dict, Optional, Tuple

from ...typing import HueType
from .. import BaseProvider, ElementsType
from .color import RandomColor

localized = True


class Provider(BaseProvider):
    """Implement default color provider for Faker."""

    all_colors: Dict[str, str] = OrderedDict(
        (
            ("AliceBlue", "#F0F8FF"),
            ("AntiqueWhite", "#FAEBD7"),
            ("Aqua", "#00FFFF"),
            ("Aquamarine", "#7FFFD4"),
            ("Azure", "#F0FFFF"),
            ("Beige", "#F5F5DC"),
            ("Bisque", "#FFE4C4"),
            ("Black", "#000000"),
            ("BlanchedAlmond", "#FFEBCD"),
            ("Blue", "#0000FF"),
            ("BlueViolet", "#8A2BE2"),
            ("Brown", "#A52A2A"),
            ("BurlyWood", "#DEB887"),
            ("CadetBlue", "#5F9EA0"),
            ("Chartreuse", "#7FFF00"),
            ("Chocolate", "#D2691E"),
            ("Coral", "#FF7F50"),
            ("CornflowerBlue", "#6495ED"),
            ("Cornsilk", "#FFF8DC"),
            ("Crimson", "#DC143C"),
            ("Cyan", "#00FFFF"),
            ("DarkBlue", "#00008B"),
            ("DarkCyan", "#008B8B"),
            ("DarkGoldenRod", "#B8860B"),
            ("DarkGray", "#A9A9A9"),
            ("DarkGreen", "#006400"),
            ("DarkKhaki", "#BDB76B"),
            ("DarkMagenta", "#8B008B"),
            ("DarkOliveGreen", "#556B2F"),
            ("DarkOrange", "#FF8C00"),
            ("DarkOrchid", "#9932CC"),
            ("DarkRed", "#8B0000"),
            ("DarkSalmon", "#E9967A"),
            ("DarkSeaGreen", "#8FBC8F"),
            ("DarkSlateBlue", "#483D8B"),
            ("DarkSlateGray", "#2F4F4F"),
            ("DarkTurquoise", "#00CED1"),
            ("DarkViolet", "#9400D3"),
            ("DeepPink", "#FF1493"),
            ("DeepSkyBlue", "#00BFFF"),
            ("DimGray", "#696969"),
            ("DodgerBlue", "#1E90FF"),
            ("FireBrick", "#B22222"),
            ("FloralWhite", "#FFFAF0"),
            ("ForestGreen", "#228B22"),
            ("Fuchsia", "#FF00FF"),
            ("Gainsboro", "#DCDCDC"),
            ("GhostWhite", "#F8F8FF"),
            ("Gold", "#FFD700"),
            ("GoldenRod", "#DAA520"),
            ("Gray", "#808080"),
            ("Green", "#008000"),
            ("GreenYellow", "#ADFF2F"),
            ("HoneyDew", "#F0FFF0"),
            ("HotPink", "#FF69B4"),
            ("IndianRed", "#CD5C5C"),
            ("Indigo", "#4B0082"),
            ("Ivory", "#FFFFF0"),
            ("Khaki", "#F0E68C"),
            ("Lavender", "#E6E6FA"),
            ("LavenderBlush", "#FFF0F5"),
            ("LawnGreen", "#7CFC00"),
            ("LemonChiffon", "#FFFACD"),
            ("LightBlue", "#ADD8E6"),
            ("LightCoral", "#F08080"),
            ("LightCyan", "#E0FFFF"),
            ("LightGoldenRodYellow", "#FAFAD2"),
            ("LightGray", "#D3D3D3"),
            ("LightGreen", "#90EE90"),
            ("LightPink", "#FFB6C1"),
            ("LightSalmon", "#FFA07A"),
            ("LightSeaGreen", "#20B2AA"),
            ("LightSkyBlue", "#87CEFA"),
            ("LightSlateGray", "#778899"),
            ("LightSteelBlue", "#B0C4DE"),
            ("LightYellow", "#FFFFE0"),
            ("Lime", "#00FF00"),
            ("LimeGreen", "#32CD32"),
            ("Linen", "#FAF0E6"),
            ("Magenta", "#FF00FF"),
            ("Maroon", "#800000"),
            ("MediumAquaMarine", "#66CDAA"),
            ("MediumBlue", "#0000CD"),
            ("MediumOrchid", "#BA55D3"),
            ("MediumPurple", "#9370DB"),
            ("MediumSeaGreen", "#3CB371"),
            ("MediumSlateBlue", "#7B68EE"),
            ("MediumSpringGreen", "#00FA9A"),
            ("MediumTurquoise", "#48D1CC"),
            ("MediumVioletRed", "#C71585"),
            ("MidnightBlue", "#191970"),
            ("MintCream", "#F5FFFA"),
            ("MistyRose", "#FFE4E1"),
            ("Moccasin", "#FFE4B5"),
            ("NavajoWhite", "#FFDEAD"),
            ("Navy", "#000080"),
            ("OldLace", "#FDF5E6"),
            ("Olive", "#808000"),
            ("OliveDrab", "#6B8E23"),
            ("Orange", "#FFA500"),
            ("OrangeRed", "#FF4500"),
            ("Orchid", "#DA70D6"),
            ("PaleGoldenRod", "#EEE8AA"),
            ("PaleGreen", "#98FB98"),
            ("PaleTurquoise", "#AFEEEE"),
            ("PaleVioletRed", "#DB7093"),
            ("PapayaWhip", "#FFEFD5"),
            ("PeachPuff", "#FFDAB9"),
            ("Peru", "#CD853F"),
            ("Pink", "#FFC0CB"),
            ("Plum", "#DDA0DD"),
            ("PowderBlue", "#B0E0E6"),
            ("Purple", "#800080"),
            ("Red", "#FF0000"),
            ("RosyBrown", "#BC8F8F"),
            ("RoyalBlue", "#4169E1"),
            ("SaddleBrown", "#8B4513"),
            ("Salmon", "#FA8072"),
            ("SandyBrown", "#F4A460"),
            ("SeaGreen", "#2E8B57"),
            ("SeaShell", "#FFF5EE"),
            ("Sienna", "#A0522D"),
            ("Silver", "#C0C0C0"),
            ("SkyBlue", "#87CEEB"),
            ("SlateBlue", "#6A5ACD"),
            ("SlateGray", "#708090"),
            ("Snow", "#FFFAFA"),
            ("SpringGreen", "#00FF7F"),
            ("SteelBlue", "#4682B4"),
            ("Tan", "#D2B48C"),
            ("Teal", "#008080"),
            ("Thistle", "#D8BFD8"),
            ("Tomato", "#FF6347"),
            ("Turquoise", "#40E0D0"),
            ("Violet", "#EE82EE"),
            ("Wheat", "#F5DEB3"),
            ("White", "#FFFFFF"),
            ("WhiteSmoke", "#F5F5F5"),
            ("Yellow", "#FFFF00"),
            ("YellowGreen", "#9ACD32"),
        )
    )

    safe_colors: ElementsType[str] = (
        "black",
        "maroon",
        "green",
        "navy",
        "olive",
        "purple",
        "teal",
        "lime",
        "blue",
        "silver",
        "gray",
        "yellow",
        "fuchsia",
        "aqua",
        "white",
    )

    def color_name(self) -> str:
        """
        Generate a color name.

        :sample:
        """
        return self.random_element(self.all_colors.keys())

    def safe_color_name(self) -> str:
        """
        Generate a web-safe color name.

        :sample:
        """
        return self.random_element(self.safe_colors)

    def hex_color(self) -> str:
        """
        Generate a color formatted as a hex triplet.

        :sample:
        """
        return f"#{self.random_int(1, 16777215):06x}"

    def safe_hex_color(self) -> str:
        """
        Generate a web-safe color formatted as a hex triplet.

        :sample:
        """
        return f"#{self.random_int(0, 15) * 17:02x}{self.random_int(0, 15) * 17:02x}{self.random_int(0, 15) * 17:02x}"

    def rgb_color(self) -> str:
        """
        Generate a color formatted as a comma-separated RGB value.

        :sample:
        """
        return ",".join(map(str, (self.random_int(0, 255) for _ in range(3))))

    def rgb_css_color(self) -> str:
        """
        Generate a color formatted as a CSS rgb() function.

        :sample:
        """
        return f"rgb({self.random_int(0, 255)},{self.random_int(0, 255)},{self.random_int(0, 255)})"

    @cached_property
    def _random_color(self):
        return RandomColor(self.generator)

    def color(
        self,
        hue: Optional[HueType] = None,
        luminosity: Optional[str] = None,
        color_format: str = "hex",
    ) -> str:
        """Generate a color in a human-friendly way.

        Under the hood, this method first creates a color represented in the HSV
        color model and then converts it to the desired ``color_format``. The
        argument ``hue`` controls the H value according to the following
        rules:

        - If the value is a number from ``0`` to ``360``, it will serve as the H
          value of the generated color.
        - If the value is a tuple/list of 2 numbers from 0 to 360, the color's H
          value will be randomly selected from that range.
        - If the value is a valid string, the color's H value will be randomly
          selected from the H range corresponding to the supplied string. Valid
          values are ``'monochrome'``, ``'red'``, ``'orange'``, ``'yellow'``,
          ``'green'``, ``'blue'``, ``'purple'``, and ``'pink'``.

        The argument ``luminosity`` influences both S and V values and is
        partially affected by ``hue`` as well. The finer details of this
        relationship are somewhat involved, so please refer to the source code
        instead if you wish to dig deeper. To keep the interface simple, this
        argument either can be omitted or can accept the following string
        values:``'bright'``, ``'dark'``, ``'light'``, or ``'random'``.

        The argument ``color_format`` controls in which color model the color is
        represented. Valid values are ``'hsv'``, ``'hsl'``, ``'rgb'``, or
        ``'hex'`` (default).

        :sample: hue='red'
        :sample: luminosity='light'
        :sample: hue=(100, 200), color_format='rgb'
        :sample: hue='orange', luminosity='bright'
        :sample: hue=135, luminosity='dark', color_format='hsv'
        :sample: hue=(300, 20), luminosity='random', color_format='hsl'
        """
        return self._random_color.generate(
            hue=hue,
            luminosity=luminosity,
            color_format=color_format,
        )

    def color_rgb(
        self,
        hue: Optional[HueType] = None,
        luminosity: Optional[str] = None,
    ) -> Tuple[int, int, int]:
        """
        Generate a RGB color tuple of integers.

        :sample:
        :sample: hue='red', luminosity='dark'
        :sample: hue=(100, 200), luminosity='random'
        """
        return self._random_color.generate_rgb(hue=hue, luminosity=luminosity)

    def color_rgb_float(
        self,
        hue: Optional[HueType] = None,
        luminosity: Optional[str] = None,
    ) -> Tuple[float, float, float]:
        """
        Generate a RGB color tuple of floats.

        :sample:
        :sample: hue='red', luminosity='dark'
        :sample: hue=(100, 200), luminosity='random'
        """
        return self._random_color.generate_rgb_float(hue=hue, luminosity=luminosity)

    def color_hsl(
        self,
        hue: Optional[HueType] = None,
        luminosity: Optional[str] = None,
    ) -> Tuple[int, int, int]:
        """
        Generate a HSL color tuple.

        :sample:
        :sample: hue='red', luminosity='dark'
        :sample: hue=(100, 200), luminosity='random'
        """
        return self._random_color.generate_hsl(hue=hue, luminosity=luminosity)

    def color_hsv(
        self,
        hue: Optional[HueType] = None,
        luminosity: Optional[str] = None,
    ) -> Tuple[int, int, int]:
        """
        Generate a HSV color tuple.

        :sample:
        :sample: hue='red', luminosity='dark'
        :sample: hue=(100, 200), luminosity='random'
        """
        return self._random_color.generate_hsv(hue=hue, luminosity=luminosity)



from .. import Provider as JobProvider


class Provider(JobProvider):
    """Translated from Super class"""

    jobs = (
        "Administrátor, umenie",
        "Administrátor, štátna služba",
        "Advokát",
        "Advokát pre ochranné známky",
        "Akademický knihovník",
        "Akupunkturista",
        "Analytický chemik",
        "Analytik finančného rizika",
        "Angličtina ako lektorka cudzieho jazyka",
        "Angličtina ako učiteľka druhého jazyka",
        "Animátor",
        "Arborista",
        "Archeológ",
        "Architekt",
        "Architektonický technológ",
        "Archivár",
        "Arteterapeut",
        "Asistent politika",
        "Astronóm",
        "Audiologický vedec",
        "Automobilový inžinier",
        "Autorizovaný likvidátor strát",
        "Autorizovaný účtovník",
        "Autorizovaný účtovník v oblasti verejných financií",
        "Bankár",
        "Banský inžinier",
        "Barista",
        "Biochemik, klinický",
        "Biomedicínsky inžinier",
        "Biomedicínsky vedec",
        "Bylinkár",
        "Bytový manažér / referent",
        "Charitatívny úradník",
        "Chemický inžinier",
        "Chemik, analytický",
        "Chiropraktik",
        "Chirurg",
        "Copywriter, reklama",
        "Cytogenetik",
        "Daňový poradca",
        "Detská sestra",
        "Detský psychoterapeut",
        "Diagnostický rádiograf",
        "Dietológ",
        "Dizajnér, fúkané sklo / vitráž",
        "Dizajnér, grafik",
        "Dizajnér, interiér / priestor",
        "Dizajnér, keramika / hrnčiarstvo",
        "Dizajnér, multimédiá",
        "Dizajnér, móda / oblečenie",
        "Dizajnér, nábytok",
        "Dizajnér, priemyselný / produkt",
        "Dizajnér, televízia / film",
        "Dizajnér, textil",
        "Dizajnér, výstava / výstava",
        "Dizajnér, šperky",
        "Docent",
        "Dodávateľ",
        "Dospelý poradenský pracovník",
        "Dozorca",
        "Dramatický terapeut",
        "Dôstojník obchodného námorníctva",
        "Dôstojník pre ochranu prírody",
        "Dôstojník pre výcvik a vzdelávanie ozbrojených síl",
        "Editor funkcie časopisu",
        "Ekológ",
        "Ekonóm",
        "Elektroinžinier",
        "Embryológ, klinický",
        "Energetický inžinier",
        "Energetický manažér",
        "Environmentálny manažér",
        "Ergonóm",
        "Farebný technológ",
        "Farmaceut Spoločenstva",
        "Farmakológ",
        "Filmový / video editor",
        "Financny kontrolor",
        "Finančný manažér",
        "Finančný obchodník",
        "Finančný plánovač",
        "Finančný poradca",
        "Finančný riaditeľ",
        "Firemná sekretárka",
        "Fotograf",
        "Fytoterapeut",
        "Fyzik zdravia",
        "Fyzik, lekár",
        "Fyziologický vedec",
        "Fyziológ cvičenia",
        "Fyzioterapeut",
        "Fúkač skla / dizajnér",
        "Genetik, molekulárny",
        "Geochemik",
        "Geodet minerálov",
        "Geodet poistného rizika",
        "Geofyzik / terénny seizmológ",
        "Geológ, strojárstvo",
        "Geológ",
        "Geovedec",
        "Grafický dizajnér",
        "Grafik",
        "Hasič",
        "Hematológ",
        "Herec",
        "Herpetológ",
        "Hlavný marketingový riaditeľ",
        "Homeopat",
        "Hotelový manažér",
        "Hudobník",
        "Hudobný lektor",
        "Hudobný terapeut",
        "Hutník",
        "Hydrogeológ",
        "Hydrografický geodet",
        "Hydrológ",
        "Hygienik práce",
        "IT konzultant",
        "Ilustrátor",
        "Imunológ",
        "Informačný úradník",
        "Investičný analytik",
        "Investičný bankár, funkčný",
        "Investičný bankár, podnikový",
        "Inšpektor / hodnotiteľ reklamácií",
        "Inšpektor historických budov / referent pamiatkovej starostlivosti",
        "Inšpektor plánovania a rozvoja",
        "Inšpektor zdravia a bezpečnosti",
        "Inžinier budov",
        "Inžinier elektroniky",
        "Inžinier kontroly a prístrojového vybavenia",
        "Inžinier poľnohospodárstva",
        "Inžinier pre automobilový priemysel",
        "Inžinier výrobných systémov",
        "Inžinier, baníctvo",
        "Inžinier, biomedicínsky",
        "Inžinier, chemický",
        "Inžinier, elektronika",
        "Inžinier, elektrotechnik",
        "Inžinier, energia",
        "Inžinier, komunikácia",
        "Inžinier, letecký",
        "Inžinier, materiály",
        "Inžinier, pozemok",
        "Inžinier, poľnohospodár",
        "Inžinier, riadenie a prístrojové vybavenie",
        "Inžinier, ropa",
        "Inžinier, statik",
        "Inžinier, stavebné služby",
        "Inžinier, stavebný (zmluvný)",
        "Inžinier, stavebný inžinier (poradenstvo)",
        "Inžinier, technický predaj",
        "Inžinier, voda",
        "Inžinier, vysielanie (prevádzka)",
        "Inžinier, výroba",
        "Inžinier, výroba",
        "Inžinier, výrobné systémy",
        "Inžinier, vŕtanie",
        "Inžinier, web",
        "Inžinier, údržba",
        "Inžinier, údržba (IT)",
        "Inžiniersky geológ",
        "Kameraman",
        "Kariérny informačný úradník",
        "Kariérny poradca",
        "Kariérny poradca pre vysokoškolské vzdelávanie",
        "Kartograf",
        "Klinický biochemik",
        "Klinický cytogenetik",
        "Klinický embryológ",
        "Klinický molekulárny genetik",
        "Klinický psychológ",
        "Klinický vedec, histokompatibilita a imunogenetika",
        "Knihovník",
        "Knihovník, verejný",
        "Kníhkupec",
        "Komerčný / rezidenčný geodet",
        "Komerčný záhradník",
        "Komunikačný inžinier",
        "Komunitný umelecký pracovník",
        "Konateľ spoločnosti",
        "Kontrolór",
        "Konzervátor / reštaurátor nábytku",
        "Konzervátor múzea / galérie",
        "Konzervátor, múzeum / galéria",
        "Konzervátor, nábytok",
        "Konzultant pre dôchodky",
        "Konzultácia so stavebným inžinierom",
        "Koordinátor dobrovoľníctva",
        "Kupujúci, maloobchod",
        "Kurátor",
        "Kurátor múzea / galérie",
        "Lektor ďalšieho vzdelávania",
        "Lektor, vysokoškolské vzdelanie",
        "Lektor, ďalšie vzdelávanie",
        "Lekár všeobecného lekára",
        "Lekár, nemocnica",
        "Lekár, všeobecná prax",
        "Lekárnik, komunita",
        "Lekárnik, nemocnica",
        "Lekársky fyzik",
        "Lekársky ilustrátor",
        "Lekársky obchodný zástupca",
        "Lekársky sekretár",
        "Lekársky technický pracovník",
        "Letecký dispečer",
        "Letecký inžinier",
        "Letecký sprostredkovateľ",
        "Lexikograf",
        "Licencovaný dopravca",
        "Lobista",
        "Logistika / podpora / administratívny dôstojník ozbrojených síl",
        "Manažér call centra",
        "Manažér cestovnej kancelárie",
        "Manažér divadelnej scény",
        "Manažér farmy",
        "Manažér fitnescentra",
        "Manažér informačných systémov",
        "Manažér komerčnej umeleckej galérie",
        "Manažér logistiky a distribúcie",
        "Manažér stravovania",
        "Manažér umeleckej galérie",
        "Manažér zariadení",
        "Manažér zábavného parku",
        "Manžérsky konzultant",
        "Marketingový manažér",
        "Materiálový inžinier",
        "Mediálny plánovač",
        "Meteorológ",
        "Mikrobiológ",
        "Moderátor, vysielanie",
        "Morský vedec",
        "Multimediálne programy",
        "Módny návrhár",
        "Najlepší chlapec",
        "Nemocničný lekár",
        "Nemocničný lekárnik",
        "Neurochirurg",
        "Novinár novín",
        "Novinár časopisu",
        "Novinár, noviny",
        "Novinár, vysielanie",
        "Novinár, časopis",
        "Nákupca médií",
        "Nákupca, priemyselný",
        "Námorný architekt",
        "Návrhár interiérov a priestorov",
        "Návrhár nábytku",
        "Návrhár výstavy",
        "Návrhár šperkov",
        "Návrhárka keramiky",
        "Obchodník s akciami",
        "Obchodník s dlhopismi",
        "Obchodník s futures",
        "Oceánograf",
        "Ochranár, historické budovy",
        "Odborník na životné prostredie",
        "Odevný / textilný technológ",
        "Onkológ",
        "Operatívny výskumník",
        "Operačný dôstojník diplomatických služieb",
        "Operačný dôstojník ozbrojených síl",
        "Optik, výdaj",
        "Optometristu",
        "Organizácia podujatia",
        "Ortoptista",
        "Osobný asistent",
        "Osteopat",
        "Očný lekár",
        "Palubní sprievodcovia",
        "Patent attorney",
        "Patológ",
        "Pedagogický psychológ",
        "Pedikér",
        "Personalista",
        "Pilot leteckej spoločnosti",
        "Plánovač dopravy",
        "Plánovač reklamného účtu",
        "Plánovač tlače",
        "Podnikový investičný bankár",
        "Podnikový pokladník",
        "Poistný matematik",
        "Poisťovací maklér",
        "Poisťovateľ",
        "Police officer",
        "Poradca pre zdravie a bezpečnosť",
        "Poradca pre životné prostredie",
        "Poradenská pracovníčka",
        "Poradenský psychológ",
        "Posádka",
        "Potravinársky technológ",
        "Poľnohospodársky konzultant",
        "Pracovník medzinárodnej pomoci / rozvoja",
        "Pracovník pomoci",
        "Pracovník rozvoja komunity",
        "Pracovník s mládežou",
        "Pracovný psychológ",
        "Pracovný terapeut",
        "Predajca",
        "Prekladateľ",
        "Prevádzkovateľ televíznej kamery",
        "Prevádzkový geológ",
        "Prevádzkový investičný bankár",
        "Prevádzkový riaditeľ",
        "Priemyselný / produktový dizajnér",
        "Priemyselný kupujúci",
        "Prieskumník trhu",
        "Prieskumový pracovník",
        "Probačný úradník",
        "Producent, rádio",
        "Producent, televízia / film / video",
        "Production assistant, radio",
        "Production assistant, television",
        "Production designer, theatre/television/film",
        "Production engineer",
        "Production manager",
        "Produktový dizajnér",
        "Produktový manažér",
        "Professor Emeritus",
        "Programme researcher, broadcasting/film/video",
        "Programmer, applications",
        "Programmer, multimedia",
        "Programmer, systems",
        "Proofreader",
        "Právnik",
        "Právny tajomník",
        "Prázdninový zástupca",
        "Psychiatric nurse",
        "Psychiatrist",
        "Psychologist, clinical",
        "Psychologist, counselling",
        "Psychologist, educational",
        "Psychologist, forensic",
        "Psychologist, occupational",
        "Psychologist, prison and probation services",
        "Psychologist, sport and exercise",
        "Psychoterapeut tanečného pohybu",
        "Psychoterapeut",
        "Pôda",
        "Pôrodná asistentka",
        "Manažér kvality",
        "Radca",
        "Realitný maklér",
        "Redaktor, uvedenie do prevádzky",
        "Redakčný asistent",
        "Referent cestovného ruchu",
        "Referent environmentálnej výchovy",
        "Referent geografických informačných systémov",
        "Referent komunitného vzdelávania",
        "Referent múzejného vzdelávania",
        "Referent obchodných noriem",
        "Referent ochrany prírody",
        "Referent odbornej prípravy a rozvoja",
        "Referent odborového výskumu",
        "Referent poľných pokusov",
        "Referent pre núdzové plánovanie / riadenie",
        "Referent pre rovnosť a rozmanitosť",
        "Referent pre výstavy v múzeách / galériách",
        "Referent rozvoja umenia",
        "Referent technickej podpory IT",
        "Referent výstavy, múzeum / galéria",
        "Referent ľudských zdrojov",
        "Referent školstva pre životné prostredie",
        "Referent školstva, komunita",
        "Referent školstva, múzeum",
        "Regulátor strát, objednaný",
        "Reklamný textár",
        "Reklamný umelecký riaditeľ",
        "Riaditeľ pre stratégiu",
        "Ropný inžinier",
        "Rozvojový pracovník, komunita",
        "Rozvojový pracovník, medzinárodná pomoc",
        "Rýchly streamer pre štátnu službu",
        "Sanitka",
        "Sestra pre dospelých",
        "Sestra pre duševné zdravie",
        "Sestra s poruchami učenia",
        "Sestra, detská",
        "Sestra, dospelý",
        "Sestra, porucha učenia",
        "Sieťový inžinier",
        "Spisovateľ",
        "Spolupracovník pre klinický výskum",
        "Spracovateľ geofyzikálnych údajov",
        "Spravodajský analytik",
        "Správca",
        "Správca databázy",
        "Správca dedičstva",
        "Správca dôchodkového systému",
        "Správca lesov a lesov",
        "Správca nehnuteľnosti / pozemkový agent",
        "Správca poistného účtu",
        "Správca polohy",
        "Správca spracovania údajov",
        "Správca umenia",
        "Správca zákazníckeho centra",
        "Správca školstva",
        "Správca štátnej služby",
        "Správca, charitatívne / dobrovoľnícke organizácie",
        "Správca, miestna samospráva",
        "Správca, vzdelávanie",
        "Správca, šport",
        "Stavebný geodet",
        "Stavebný inžinier, poradenstvo",
        "Stavebný inžinier, uzatváranie zmlúv",
        "Strihač, film / video",
        "Strojný inžinier",
        "Strážca / strážca",
        "Svetelný technik, vysielanie / film / video",
        "Súdny psychológ",
        "Súdny vedec",
        "Súkromný učiteľ hudby",
        "Tanečnica",
        "Technický dôstojník ozbrojených síl",
        "Technik údržby",
        "Technológ pre zvieratá",
        "Technológ varenia piva",
        "Terapeut, dráma",
        "Terapeut, hudba",
        "Terapeut, záhradnícky",
        "Terapeut, šport",
        "Terénny seizmológ",
        "Tlačový fotograf",
        "Tlmočník",
        "Toxikológ",
        "Umelec",
        "Urobiť",
        "Uvádzací redaktor",
        "Učiaci sa mentor",
        "Učiteľ v ranom detstve",
        "Učiteľ, angličtina ako cudzí jazyk",
        "Učiteľ, hudba",
        "Učiteľ, prvé roky / pred",
        "Učiteľ, vzdelávanie dospelých",
        "Učiteľ, základná škola",
        "Učiteľka na základnej škole",
        "Vedec dát",
        "Vedec pre kvalitu vody",
        "Vedec vývoja produktov / procesov",
        "Vedecký pracovník lekárskeho laboratória",
        "Vedúci kancelárie",
        "Vedúci konferenčného centra",
        "Vedúci osobnej dopravy",
        "Vedúci outdoorových aktivít / vzdelávania",
        "Vedúci reklamného účtu",
        "Vedúci reštaurácie rýchleho občerstvenia",
        "Vedúci rybej farmy",
        "Vedúci skladu",
        "Vedúci strediska voľného času",
        "Vedúci turistického informačného centra",
        "Vedúci ubytovania",
        "Vedúci zdravotníckej služby",
        "Vedúci úseku",
        "Veterinárny chirurg",
        "Video editor",
        "Vizuálny obchodník",
        "Vládny úradník pre sociálny výskum",
        "Vodný inžinier",
        "Vrtný inžinier",
        "Vybavenie záhradník",
        "Vybavovač poistných udalostí",
        "Vysielaný novinár",
        "Vysokoškolský lektor",
        "Výdajný optik",
        "Výkonný riaditeľ",
        "Výkonný technický riaditeľ",
        "Výrobný inžinier",
        "Výtvarný umelec",
        "Vývojár aplikácií",
        "Vývojár hier",
        "Vývojár počítačových hier",
        "Vývojár systémov",
        "Výživový poradca pre zvieratá",
        "Výživový terapeut",
        "Web dizajnér",
        "Wellsite geológ",
        "Zamestnanec imigračného úradu",
        "Zdravotná sestra, duševné zdravie",
        "Zdravotný návštevník",
        "Zememerač / geomatik",
        "Zmluvný stavebný inžinier",
        "Zubár",
        "Záchranár",
        "Záhradnícky konzultant",
        "Záhradnícky terapeut",
        "Záhradník, komerčný",
        "Záhradník, vybavenosť",
        "Záhradný architekt",
        "Záznamník bahna",
        "Úradník miestnej samosprávy",
        "Úradník pre rybolov",
        "Účtovník, autorizované verejné financie",
        "Účtovník, autorizovaný",
        "Účtovník, autorizovaný certifikovaný",
        "Účtovník, autorizovaný manažment",
        "Účtovný technik",
        "Špecialista na multimédiá",
        "Špecialista na podporu zdravia",
        "Špeditér",
        "Šľachtiteľ rastlín / genetik",
    )

    def job(self) -> str:
        return self.random_element(self.jobs)



from typing import Dict, List, Optional, Tuple

from randum.providers.address import Provider as AddressProvider

Range = Tuple[int, int]


class Provider(AddressProvider):
    # City and States names taken from wikipedia
    # Street format taken from some common famous places in India
    # Link for cities: https://en.wikipedia.org/wiki/List_of_cities_in_India_by_population
    # Link for States: https://en.wikipedia.org/wiki/States_and_union_territories_of_India
    # Links for street name formats: https://www.mumbai77.com/city/3313/travel/old-new-street-names/

    city_formats = ("{{city_name}}",)

    street_name_formats = (
        "{{last_name}} Nagar",
        "{{last_name}} Zila",
        "{{last_name}} Street",
        "{{last_name}} Ganj",
        "{{last_name}} Road",
        "{{last_name}} Path",
        "{{last_name}} Marg",
        "{{last_name}} Chowk",
        "{{last_name}} Circle",
        "{{last_name}}",
    )

    street_address_formats = (
        "{{building_number}}, {{street_name}}",
        "{{building_number}}\n{{street_name}}",
    )

    address_formats = (
        "{{street_address}}\n{{city}} {{postcode}}",
        "{{street_address}}\n{{city}}-{{postcode}}",
        "{{street_address}}, {{city}} {{postcode}}",
        "{{street_address}}, {{city}}-{{postcode}}",
    )

    building_number_formats = ("H.No. ###", "###", "H.No. ##", "##", "##/##", "##/###")

    postcode_formats = ("######",)

    cities = (
        "Mumbai",
        "Delhi",
        "Kolkata",
        "Chennai",
        "Bangalore",
        "Hyderabad",
        "Ahmedabad",
        "Kanpur",
        "Pune",
        "Surat",
        "Jaipur",
        "Lucknow",
        "Nagpur",
        "Indore",
        "Bhopal",
        "Ludhiana",
        "Patna",
        "Visakhapatnam",
        "Vadodara",
        "Agra",
        "Thane",
        "Kalyan-Dombivli",
        "Varanasi",
        "Ranchi",
        "Nashik",
        "Dhanbad",
        "Faridabad",
        "Meerut",
        "Pimpri-Chinchwad",
        "Howrah",
        "Allahabad",
        "Ghaziabad",
        "Rajkot",
        "Amritsar",
        "Jabalpur",
        "Coimbatore",
        "Madurai",
        "Srinagar",
        "Aurangabad",
        "Solapur",
        "Vijayawada",
        "Jodhpur",
        "Gwalior",
        "Guwahati",
        "Chandigarh",
        "Hubli–Dharwad",
        "Mysore",
        "Tiruchirappalli",
        "Bareilly",
        "Jalandhar",
        "Navi Mumbai",
        "Salem",
        "Kota",
        "Vasai-Virar",
        "Aligarh",
        "Moradabad",
        "Bhubaneswar",
        "Gorakhpur",
        "Raipur",
        "Bhiwandi",
        "Kochi",
        "Jamshedpur",
        "Bhilai",
        "Amravati",
        "Cuttack",
        "Warangal",
        "Bikaner",
        "Mira-Bhayandar",
        "Guntur",
        "Bhavnagar",
        "Durgapur",
        "Kolhapur",
        "Ajmer",
        "Asansol",
        "Ulhasnagar",
        "Siliguri",
        "Jalgaon",
        "Saharanpur",
        "Jamnagar",
        "Bhatpara",
        "Sangli-Miraj & Kupwad",
        "Kozhikode",
        "Nanded",
        "Ujjain",
        "Dehradun",
        "Rourkela",
        "Gulbarga",
        "Tirunelveli",
        "Malegaon",
        "Akola",
        "Belgaum",
        "Mangalore",
        "Bokaro",
        "South Dumdum",
        "Udaipur",
        "Gaya",
        "Maheshtala",
        "Jhansi",
        "Nellore",
        "Jammu",
        "Thiruvananthapuram",
        "Davanagere",
        "Kollam",
        "Panihati",
        "Kurnool",
        "Tiruppur",
        "Dhule",
        "Bhagalpur",
        "Rajpur Sonarpur",
        "Kakinada",
        "Thrissur",
        "Bellary",
        "Muzaffarnagar",
        "Korba",
        "Rajahmundry",
        "Kamarhati",
        "Ambattur",
        "Berhampur",
        "Ahmednagar",
        "Muzaffarpur",
        "Noida",
        "Patiala",
        "Mathura",
        "New Delhi",
        "Latur",
        "Sambalpur",
        "Shahjahanpur",
        "Kulti",
        "Chandrapur",
        "Nizamabad",
        "Rohtak",
        "Bardhaman",
        "Rampur",
        "Bhilwara",
        "Firozabad",
        "Bilaspur",
        "Shimoga",
        "Agartala",
        "Gopalpur",
        "Darbhanga",
        "Panipat",
        "Bally",
        "Alwar",
        "Parbhani",
        "Ichalkaranji",
        "Anantapuram",
        "Baranagar",
        "Tumkur",
        "Ramagundam",
        "Jalna",
        "Durg",
        "Sagar",
        "Bihar Sharif",
        "Dewas",
        "Barasat",
        "Avadi",
        "Farrukhabad",
        "Aizawl",
        "Tirupati",
        "Bijapur",
        "Satara",
        "Satna",
        "Ratlam",
        "Imphal",
        "Pondicherry",
        "North Dumdum",
        "Anantapur",
        "Khammam",
        "Ozhukarai",
        "Bathinda",
        "Thoothukudi",
        "Thanjavur",
        "Naihati",
        "Sonipat",
        "Mau",
        "Tiruvottiyur",
        "Hapur",
        "Sri Ganganagar",
        "Karnal",
        "Etawah",
        "Nagercoil",
        "Raichur",
        "Raurkela Industrial Township",
        "Secunderabad",
        "Karimnagar",
        "Mirzapur",
        "Bharatpur",
        "Ambarnath",
        "Arrah",
        "Uluberia",
        "Serampore",
        "Dindigul",
        "Gandhinagar",
        "Burhanpur",
        "Nadiad",
        "Eluru",
        "Yamunanagar",
        "Kharagpur",
        "Munger",
        "Pali",
        "Katni",
        "Singrauli",
        "Tenali",
        "Sikar",
        "Silchar",
        "Rewa",
        "Sambhal",
        "Machilipatnam",
        "Vellore",
        "Alappuzha",
        "Bulandshahr",
        "Haridwar",
        "Vijayanagaram",
        "Erode",
        "Gurgaon",
        "Bidar",
        "Bhusawal",
        "Khandwa",
        "Purnia",
        "Haldia",
        "Chinsurah",
        "Bhiwani",
        "Raebareli",
        "Junagadh",
        "Bahraich",
        "Gandhidham",
        "Mango",
        "Raiganj",
        "Amroha",
        "Sultan Pur Majra",
        "Hospet",
        "Bidhannagar",
        "Malda",
        "Sirsa",
        "Berhampore",
        "Jaunpur",
        "Surendranagar Dudhrej",
        "Madhyamgram",
        "Kirari Suleman Nagar",
        "Bhind",
        "Nandyal",
        "Chittoor",
        "Bhalswa Jahangir Pur",
        "Fatehpur",
        "Morena",
        "Nangloi Jat",
        "Ongole",
        "Karawal Nagar",
        "Shivpuri",
        "Morbi",
        "Unnao",
        "Pallavaram",
        "Kumbakonam",
        "Shimla",
        "Mehsana",
        "Panchkula",
        "Orai",
        "Ambala",
        "Dibrugarh",
        "Guna",
        "Danapur",
        "Sasaram",
        "Anand",
        "Kottayam",
        "Hazaribagh",
        "Kadapa",
        "Saharsa",
        "Nagaon",
        "Loni",
        "Hajipur",
        "Dehri",
        "Bettiah",
        "Katihar",
        "Deoghar",
        "Jorhat",
        "Siwan",
        "Panvel",
        "Hosur",
        "Tinsukia",
        "Bongaigaon",
        "Motihari",
        "Jamalpur",
        "Suryapet",
        "Begusarai",
        "Miryalaguda",
        "Proddatur",
        "Karaikudi",
        "Kishanganj",
        "Phusro",
        "Buxar",
        "Tezpur",
        "Jehanabad",
        "Aurangabad",
        "Chapra",
        "Ramgarh",
        "Gangtok",
        "Adoni",
        "Amaravati",
        "Ballia",
        "Bhimavaram",
        "Dharmavaram",
        "Giridih",
        "Gudivada",
        "Guntakal",
        "Hindupur",
        "Kavali",
        "Khora ",
        "Ghaziabad",
        "Madanapalle",
        "Mahbubnagar",
        "Medininagar",
        "Narasaraopet",
        "Phagwara",
        "Pudukkottai",
        "Srikakulam",
        "Tadepalligudem",
        "Tadipatri",
        "Udupi",
    )

    states = (
        "Andhra Pradesh",
        "Arunachal Pradesh",
        "Assam",
        "Bihar",
        "Chhattisgarh",
        "Goa",
        "Gujarat",
        "Haryana",
        "Himachal Pradesh",
        "Jharkhand",
        "Karnataka",
        "Kerala",
        "Madhya Pradesh",
        "Maharashtra",
        "Manipur",
        "Meghalaya",
        "Mizoram",
        "Nagaland",
        "Odisha",
        "Punjab",
        "Rajasthan",
        "Sikkim",
        "Tamil Nadu",
        "Telangana",
        "Tripura",
        "Uttar Pradesh",
        "Uttarakhand",
        "West Bengal",
    )

    states_abbr: Tuple[str, ...] = (
        "AP",
        "AR",
        "AS",
        "BR",
        "CG",
        "GA",
        "GJ",
        "HR",
        "HP",
        "JH",
        "KA",
        "KL",
        "MP",
        "MH",
        "MN",
        "ML",
        "MZ",
        "NL",
        "OD",
        "PB",
        "RJ",
        "SK",
        "TN",
        "TG",
        "TR",
        "UK",
        "UP",
        "WB",
    )

    union_territories = (
        ("Andaman and Nicobar Islands",),
        ("Chandigarh",),
        ("Dadra and Nagar Haveli, Dadra & Nagar Haveli",),
        ("Daman and Diu",),
        ("Delhi, National Capital Territory of Delhi",),
        ("Jammu and Kashmir",),
        ("Ladakh",),
        ("Lakshadweep",),
        ("Pondicherry",),
        ("Puducherry",),
    )

    union_territories_abbr = (
        "AN",
        "CH",
        "DN",
        "DD",
        "DL",
        "JK",
        "LA",
        "LD",
        "PY",
    )

    # https://en.wikipedia.org/wiki/Postal_Index_Number

    # FIXME: Some states such as `BR/JH` / `UK/UP` have similar PIN code ranges
    # FIXME: as mentioned in above link.

    state_pincode: Dict[str, List[Range]] = {
        "AP": [(510_000, 539_999)],
        "AR": [(790_000, 792_999)],
        "AS": [(780_000, 789_999)],
        "BR": [(800_000, 859_999)],
        "CG": [(490_000, 499_999)],
        "GA": [(403_000, 403_999)],
        "GJ": [(360_000, 399_999)],
        "HR": [(120_000, 139_999)],
        "HP": [(170_000, 179_999)],
        "JH": [(800_000, 859_999)],
        "KA": [(560_000, 599_999)],
        "KL": [(670_000, 681_999), (683_000, 699_999)],
        "MP": [(450_000, 489_999)],
        "MH": [(400_000, 402_999), (404_000, 449_999)],
        "MN": [(795_000, 795_999)],
        "ML": [(793_000, 794_999)],
        "MZ": [(796_000, 796_999)],
        "NL": [(797_000, 798_999)],
        "OD": [(750_000, 779_999)],
        "PB": [(140_000, 159_999)],
        "RJ": [(300_000, 349_999)],
        "SK": [(737_000, 737_999)],
        "TN": [(600_000, 669_999)],
        "TG": [(500_000, 509_999)],
        "TR": [(799_000, 799_999)],
        "UK": [(200_000, 289_999)],
        "UP": [(200_000, 289_999)],
        "WB": [(700_000, 736_999), (738_000, 743_999), (745_000, 749_999)],
    }

    union_territories_pincode: Dict[str, List[Range]] = {
        "AN": [(744_000, 744_999)],
        "CH": [(160_000, 169_999)],
        "DN": [(396_000, 396_999)],
        "DD": [(396_000, 396_999)],
        "DL": [(110_000, 119_999)],
        "JK": [(180_000, 199_999)],
        "LA": [(180_000, 199_999)],
        "LD": [(682_000, 682_999)],
        "PY": [(605_000, 605_999)],
    }

    army_pincode: Dict[str, Range] = {"APS": (900_000, 999_999)}

    def city_name(self) -> str:
        return self.random_element(self.cities)

    def administrative_unit(self) -> str:
        return self.random_element(self.states)

    state = administrative_unit

    def union_territory(self) -> str:
        """Returns random union territory name"""

        return self.random_element(self.union_territories)[0]

    def pincode_in_state(self, state_abbr: Optional[str] = None, include_union_territories: bool = False) -> int:
        """Random PIN Code within provided state abbreviation

        :param state_abbr: State Abbr, defaults to None
        :param include_union_territories: Include Union Territories ?, defaults to False
        :raises ValueError: If incorrect state abbr
        :return: PIN Code
        """

        known_abbrs = self.states_abbr
        if include_union_territories:
            known_abbrs += self.union_territories_abbr

        if state_abbr is None:
            state_abbr = self.random_element(known_abbrs)

        if state_abbr in known_abbrs:
            codes = self.state_pincode
            if include_union_territories:
                codes.update(self.union_territories_pincode)

            pincode_range = self.random_element(codes[state_abbr])

            return self.generator.random.randint(*pincode_range)

        raise ValueError("State Abbreviation not found in list")

    def pincode_in_military(self) -> int:
        """Random PIN Code within Army Postal Service range"""

        key: str = self.random_element(self.army_pincode.keys())

        return self.generator.random.randint(*self.army_pincode[key])

    # Aliases

    def zipcode_in_state(self, state_abbr: Optional[str] = None, include_union_territories: bool = False) -> int:
        return self.pincode_in_state(state_abbr, include_union_territories)

    def postcode_in_state(self, state_abbr: Optional[str] = None, include_union_territories: bool = False) -> int:
        return self.pincode_in_state(state_abbr, include_union_territories)

    def pincode_in_army(self) -> int:
        return self.pincode_in_military()

    def zipcode_in_military(self) -> int:
        return self.pincode_in_military()

    def zipcode_in_army(self) -> int:
        return self.pincode_in_military()

    def postcode_in_military(self) -> int:
        return self.pincode_in_military()

    def postcode_in_army(self) -> int:
        return self.pincode_in_military()



from .. import Provider as PhoneNumberProvider


class Provider(PhoneNumberProvider):
    formats = (
        "070-####-####",
        "080-####-####",
        "090-####-####",
        "##-####-####",
    )



from datetime import date
from typing import List, Optional

from .. import Provider as BaseProvider


class Provider(BaseProvider):
    """
    A Faker provider for the Austrian VAT IDs
    """

    vat_id_formats = ("ATU########",)

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: a random Austrian VAT ID
        """

        return self.bothify(self.random_element(self.vat_id_formats))

    def __get_check_digit(self, ssn_without_checkdigit: str) -> int:
        factors: List[int] = [3, 7, 9, 5, 8, 4, 2, 1, 6]
        ssn_numbers: List[int] = [int(char) for char in ssn_without_checkdigit]

        sum: int = 0
        for index, factor in enumerate(factors):
            sum += ssn_numbers[index] * factor

        check_digit = sum % 11

        return check_digit

    def ssn(self, birthdate: Optional[date] = None) -> str:
        """
        Source: https://de.wikipedia.org/wiki/Sozialversicherungsnummer#Berechnung
        :return: a random valid Austrian social security number
        """
        _birthdate = birthdate or self.generator.date_object()
        format: str = f"%##{_birthdate:%d%m%y}"
        ssn: str = self.numerify(format)
        check_digit: int = self.__get_check_digit(ssn)

        while check_digit > 9:
            ssn = self.numerify(format)
            check_digit = self.__get_check_digit(ssn)

        return ssn[:3] + str(self.__get_check_digit(ssn)) + ssn[3:]



import datetime

from .. import Provider as SsnProvider


class Provider(SsnProvider):
    def ssn(self, min_age: int = 0, max_age: int = 105) -> str:
        """
        Returns 11 character Latvian personal identity code (Personas kods).
        This function assigns random age to person.

        Personal code consists of eleven characters of the form DDMMYYCZZZQ, where
        DDMMYY is the date of birth, C the century sign, ZZZ the individual
        number and Q the control character (checksum). The number for the
        century is either 0 (1800–1899), 1 (1900–1999), or 2 (2000–2099).
        """

        def _checksum(ssn_without_checksum):
            weights = [1, 6, 3, 7, 9, 10, 5, 8, 4, 2]
            weighted_sum = sum(int(digit) * weight for digit, weight in zip(ssn_without_checksum, weights))
            reminder = (1 - weighted_sum) % 11
            if reminder == 10:
                return 0
            elif reminder < -1:
                return reminder + 11
            return reminder

        age = datetime.timedelta(days=self.generator.random.randrange(min_age * 365, max_age * 365))
        birthday = datetime.date.today() - age
        ssn_date = f"{birthday:%d%m%y}"
        century = self._get_century_code(birthday.year)  # Century
        suffix = self.generator.random.randrange(111, 999)
        checksum = _checksum(f"{ssn_date}{century:01d}{suffix:03d}")
        ssn = f"{ssn_date}-{century:01d}{suffix:03d}{checksum:01d}"
        return ssn

    @staticmethod
    def _get_century_code(year: int) -> int:
        """Returns the century code for a given year"""
        if 2000 <= year < 3000:
            code = 2
        elif 1900 <= year < 2000:
            code = 1
        elif 1800 <= year < 1900:
            code = 0
        else:
            raise ValueError("SSN do not support people born before the year 1800 or after the year 2999")
        return code

    """
    A Faker provider for the Latvian VAT IDs
    """

    vat_id_formats = ("LV###########",)

    def vat_id(self) -> str:
        """
        http://ec.europa.eu/taxation_customs/vies/faq.html#item_11
        :return: a random Latvian VAT ID
        """

        return self.bothify(self.random_element(self.vat_id_formats))



from typing import Dict

from .. import Provider as LoremProvider


class Provider(LoremProvider):
    """Implement lorem provider for ``cs_CZ`` locale.

    Word list is drawn from the SYN2015.
    (representative corpus of contemporary written Czech published in December 2015)

    The word list is a list of the ~5000 most common lemmas. Abbreviations and first names were removed.

    Sources:
    - https://wiki.korpus.cz/lib/exe/fetch.php/seznamy:syn2015_lemma_utf8.zip

    """

    word_list = (
        "a",
        "absence",
        "absolutně",
        "absolutní",
        "absolvent",
        "absolvovat",
        "absurdní",
        "aby",
        "ač",
        "ačkoli",
        "adresa",
        "advokát",
        "africký",
        "Afrika",
        "agent",
        "agentura",
        "agresivní",
        "aha",
        "ahoj",
        "ach",
        "aj",
        "akademický",
        "akademie",
        "akce",
        "akcie",
        "akční",
        "akorát",
        "akt",
        "aktivita",
        "aktivně",
        "aktivní",
        "aktuální",
        "ala",
        "album",
        "ale",
        "alespoň",
        "alkohol",
        "alternativa",
        "alternativní",
        "ambice",
        "americký",
        "Američan",
        "Amerika",
        "analytik",
        "analýza",
        "analyzovat",
        "and",
        "anděl",
        "android",
        "anebo",
        "anglicky",
        "anglický",
        "Angličan",
        "angličtina",
        "Anglie",
        "ani",
        "aniž",
        "anketa",
        "ano",
        "aplikace",
        "aplikovat",
        "apod",
        "Apple",
        "arabský",
        "areál",
        "argument",
        "architekt",
        "architektonický",
        "architektura",
        "archiv",
        "armáda",
        "asi",
        "Asie",
        "asistent",
        "asociace",
        "aspekt",
        "aspoň",
        "ať",
        "atd",
        "ateliér",
        "atmosféra",
        "atom",
        "atraktivní",
        "Austrálie",
        "auto",
        "autobus",
        "automat",
        "automaticky",
        "automatický",
        "automobil",
        "automobilka",
        "automobilový",
        "autor",
        "autorita",
        "autorka",
        "autorský",
        "avšak",
        "až",
        "ba",
        "babička",
        "báječný",
        "bakterie",
        "balíček",
        "balík",
        "balkón",
        "Baník",
        "banka",
        "bankovní",
        "bar",
        "barák",
        "Barcelona",
        "barevný",
        "barva",
        "báseň",
        "básník",
        "bát",
        "baterie",
        "batoh",
        "bavit",
        "báze",
        "bazén",
        "běh",
        "běhat",
        "během",
        "benzín",
        "Berlín",
        "beton",
        "betonový",
        "bez",
        "bezpečí",
        "bezpečně",
        "bezpečnost",
        "bezpečnostní",
        "bezpečný",
        "bezprostředně",
        "bezprostřední",
        "běžet",
        "běžně",
        "běžný",
        "bilance",
        "bílý",
        "biologický",
        "biskup",
        "bít",
        "bitva",
        "blázen",
        "blbý",
        "bledý",
        "blesk",
        "Blesk",
        "blízko",
        "blízkost",
        "blízký",
        "blížit",
        "blok",
        "boční",
        "bod",
        "bohatství",
        "bohatý",
        "bohužel",
        "boj",
        "bojovat",
        "bojovník",
        "bojový",
        "bok",
        "Boleslav",
        "bolest",
        "bolet",
        "bomba",
        "bota",
        "bouře",
        "box",
        "boží",
        "brada",
        "brambora",
        "brána",
        "bránit",
        "branka",
        "brankář",
        "brát",
        "bratr",
        "Brazílie",
        "brečet",
        "Británie",
        "britský",
        "brněnský",
        "Brno",
        "Brod",
        "Brusel",
        "brýle",
        "brzy",
        "břeh",
        "březen",
        "břicho",
        "buď",
        "Budějovice",
        "budit",
        "budoucí",
        "budoucno",
        "budoucnost",
        "budova",
        "budování",
        "budovat",
        "bůh",
        "bunda",
        "buňka",
        "burza",
        "bydlení",
        "bydlet",
        "byt",
        "byť",
        "být",
        "bytost",
        "bytový",
        "bývalý",
        "bývat",
        "byznys",
        "cca",
        "cela",
        "celek",
        "celkem",
        "celkově",
        "celkový",
        "celý",
        "cena",
        "cenný",
        "centimetr",
        "centrální",
        "centrum",
        "cesta",
        "cestování",
        "cestovat",
        "cestovní",
        "cestující",
        "cibule",
        "cigareta",
        "cihla",
        "cíl",
        "cílový",
        "církev",
        "církevní",
        "císař",
        "císařský",
        "cit",
        "cítit",
        "citlivý",
        "citovat",
        "civilizace",
        "cizí",
        "cizina",
        "cizinec",
        "cm",
        "co",
        "coby",
        "cokoli",
        "copak",
        "cosi",
        "což",
        "cukr",
        "cup",
        "cvičení",
        "cvičit",
        "cyklista",
        "cyklus",
        "čaj",
        "čára",
        "čas",
        "časopis",
        "časový",
        "část",
        "částečně",
        "částice",
        "částka",
        "často",
        "častý",
        "Čech",
        "Čecho",
        "Čechy",
        "čekání",
        "čekat",
        "čelist",
        "čelit",
        "čelo",
        "čepice",
        "černý",
        "čerpadlo",
        "čerpat",
        "čerstvě",
        "čerstvý",
        "čert",
        "červen",
        "červenec",
        "červený",
        "Česko",
        "Československo",
        "československý",
        "česky",
        "český",
        "Český",
        "česnek",
        "čest",
        "čestný",
        "čeština",
        "četný",
        "ČEZ",
        "či",
        "čili",
        "čin",
        "Čína",
        "činit",
        "činnost",
        "čínský",
        "číslo",
        "číst",
        "čistě",
        "čistota",
        "čistý",
        "článek",
        "člen",
        "členský",
        "člověk",
        "člun",
        "čokoláda",
        "ČR",
        "čtenář",
        "čtení",
        "čtrnáct",
        "čtvereční",
        "čtvrt",
        "čtvrť",
        "čtvrtek",
        "čtvrtina",
        "čtvrtletí",
        "čtvrtý",
        "čtyři",
        "čtyřicet",
        "dále",
        "daleko",
        "daleký",
        "dálka",
        "dálkový",
        "dálnice",
        "další",
        "dáma",
        "daň",
        "daňový",
        "daný",
        "dar",
        "dárek",
        "dařit",
        "dát",
        "data",
        "databáze",
        "datový",
        "datum",
        "dav",
        "dávat",
        "David",
        "dávka",
        "dávno",
        "dávný",
        "dbát",
        "dcera",
        "de",
        "debata",
        "děda",
        "dědeček",
        "dědictví",
        "definice",
        "definitivně",
        "definovat",
        "dech",
        "děj",
        "dějiny",
        "deka",
        "děkovat",
        "dělat",
        "dělit",
        "délka",
        "dělník",
        "demokracie",
        "demokrat",
        "demokratický",
        "den",
        "dění",
        "deník",
        "denně",
        "denní",
        "deprese",
        "desátý",
        "deset",
        "desetiletí",
        "design",
        "děsit",
        "desítka",
        "děsivý",
        "deska",
        "déšť",
        "detail",
        "detektiv",
        "dětský",
        "dětství",
        "devadesátý",
        "devátý",
        "děvče",
        "devět",
        "dialog",
        "digitální",
        "dík",
        "díky",
        "díl",
        "dílčí",
        "dílna",
        "dílo",
        "dimenze",
        "dioda",
        "díra",
        "disciplína",
        "disk",
        "diskuse",
        "diskutovat",
        "displej",
        "disponovat",
        "dispozice",
        "distribuce",
        "dít",
        "dítě",
        "div",
        "divadelní",
        "divadlo",
        "divák",
        "dívat",
        "divit",
        "divize",
        "dívka",
        "divný",
        "divoký",
        "dlaň",
        "dlažba",
        "dle",
        "dlouho",
        "dlouhodobě",
        "dlouhodobý",
        "dlouholetý",
        "dlouhý",
        "dluh",
        "dnes",
        "dneska",
        "dnešek",
        "dnešní",
        "dno",
        "do",
        "doba",
        "dobový",
        "dobro",
        "dobrodružství",
        "dobrovolně",
        "dobrovolný",
        "dobrý",
        "dobře",
        "docela",
        "dočkat",
        "dodat",
        "dodávat",
        "dodavatel",
        "dodávka",
        "dodnes",
        "dodržovat",
        "dohled",
        "dohoda",
        "dohodnout",
        "dohromady",
        "docházet",
        "dojem",
        "dojet",
        "dojít",
        "dokázat",
        "dokazovat",
        "doklad",
        "dokládat",
        "dokola",
        "dokonale",
        "dokonalý",
        "dokonce",
        "dokončení",
        "dokončit",
        "doktor",
        "dokud",
        "dokument",
        "dokumentace",
        "dolar",
        "dole",
        "dolní",
        "dolů",
        "doma",
        "domácí",
        "domácnost",
        "domek",
        "dominantní",
        "dominovat",
        "domluvit",
        "domnívat",
        "domov",
        "domů",
        "donést",
        "donutit",
        "doopravdy",
        "dopad",
        "dopadnout",
        "dopis",
        "doplněk",
        "doplnit",
        "doplňovat",
        "dopoledne",
        "doporučení",
        "doporučit",
        "doporučovat",
        "doposud",
        "doprava",
        "dopravní",
        "doprovázet",
        "doprovod",
        "dopřát",
        "dopředu",
        "dopustit",
        "dorazit",
        "dosah",
        "dosáhnout",
        "dosahovat",
        "dosavadní",
        "dosažení",
        "doslova",
        "dospělý",
        "dospět",
        "dost",
        "dostat",
        "dostatečně",
        "dostatečný",
        "dostatek",
        "dostávat",
        "dostavit",
        "dostupný",
        "dosud",
        "dotace",
        "dotáhnout",
        "dotaz",
        "dotknout",
        "dotyčný",
        "dotýkat",
        "doufat",
        "dovednost",
        "dovést",
        "dovnitř",
        "dovolená",
        "dovolit",
        "dovolovat",
        "dozadu",
        "dozvědět",
        "DPH",
        "dráha",
        "drahý",
        "drak",
        "drama",
        "dramatický",
        "drát",
        "dres",
        "drobný",
        "droga",
        "drsný",
        "druh",
        "druhý",
        "družstvo",
        "držet",
        "dřevěný",
        "dřevina",
        "dřevo",
        "dřívější",
        "duben",
        "duel",
        "duch",
        "důchod",
        "duchovní",
        "důkaz",
        "důkladně",
        "důl",
        "důležitý",
        "dům",
        "důraz",
        "důsledek",
        "důstojník",
        "duše",
        "duševní",
        "dutina",
        "důvěra",
        "důvěřovat",
        "důvod",
        "dva",
        "dvacátý",
        "dvacet",
        "dvakrát",
        "dvanáct",
        "dveře",
        "dvojče",
        "dvojí",
        "dvojice",
        "dvůr",
        "dýchat",
        "dynamický",
        "efekt",
        "efektivní",
        "Egypt",
        "ekologický",
        "ekonom",
        "ekonomický",
        "ekonomika",
        "elegantní",
        "elektrárna",
        "elektrický",
        "elektron",
        "elektronický",
        "elektřina",
        "e-mail",
        "emise",
        "emoce",
        "energetický",
        "energetika",
        "energie",
        "éra",
        "estetický",
        "et",
        "etapa",
        "EU",
        "euro",
        "eurozóna",
        "evoluce",
        "Evropa",
        "evropský",
        "existence",
        "existovat",
        "existující",
        "experiment",
        "expert",
        "expozice",
        "externí",
        "extraliga",
        "extrémní",
        "Facebook",
        "fajn",
        "fakt",
        "faktor",
        "faktum",
        "fakulta",
        "falešný",
        "fanoušek",
        "fantastický",
        "fantazie",
        "farma",
        "fasáda",
        "favorit",
        "fáze",
        "fenomén",
        "festival",
        "fialový",
        "film",
        "filmový",
        "filozof",
        "filozofický",
        "filozofie",
        "filtr",
        "finále",
        "finance",
        "financování",
        "finančně",
        "finanční",
        "firemní",
        "firma",
        "fólie",
        "fond",
        "forma",
        "formální",
        "formát",
        "fórum",
        "fotbal",
        "fotbalista",
        "fotbalový",
        "fotka",
        "foto",
        "fotoaparát",
        "fotograf",
        "fotografie",
        "Francie",
        "Francouz",
        "francouzský",
        "frekvence",
        "fronta",
        "fungování",
        "fungovat",
        "funkce",
        "funkční",
        "fyzicky",
        "fyzický",
        "fyzika",
        "fyzikální",
        "galerie",
        "garáž",
        "gen",
        "generace",
        "generál",
        "generální",
        "genetický",
        "gesto",
        "globální",
        "gól",
        "gólman",
        "Google",
        "graf",
        "grafický",
        "granát",
        "gymnázium",
        "ha",
        "had",
        "hádat",
        "hájit",
        "hala",
        "Hana",
        "hasič",
        "Havel",
        "házet",
        "hejtman",
        "hele",
        "herec",
        "herecký",
        "herečka",
        "herní",
        "heslo",
        "hezky",
        "hezký",
        "historický",
        "historie",
        "historik",
        "historka",
        "hit",
        "hlad",
        "hladina",
        "hladit",
        "hladký",
        "hlas",
        "hlásit",
        "hlasitě",
        "hlasitý",
        "hlasování",
        "hlava",
        "hlavička",
        "hlavně",
        "hlavní",
        "hledání",
        "hledat",
        "hledět",
        "hledisko",
        "hlídat",
        "hlídka",
        "hlína",
        "hloubka",
        "hloupý",
        "hluboce",
        "hluboko",
        "hluboký",
        "hluk",
        "hmota",
        "hmotnost",
        "hmotný",
        "hmyz",
        "hnát",
        "hned",
        "hnědý",
        "hněv",
        "hnízdo",
        "hnout",
        "hnutí",
        "hod",
        "hodina",
        "hodinky",
        "hodit",
        "hodlat",
        "hodně",
        "hodnocení",
        "hodnota",
        "hodnotit",
        "hodný",
        "hoch",
        "hokej",
        "hokejista",
        "hokejový",
        "holčička",
        "holka",
        "holý",
        "honit",
        "Honza",
        "hora",
        "horizont",
        "horko",
        "horký",
        "horní",
        "hornina",
        "horský",
        "hořet",
        "hospoda",
        "hospodaření",
        "hospodářský",
        "hospodářství",
        "host",
        "hotel",
        "hotový",
        "houba",
        "hovor",
        "hovořit",
        "hra",
        "hrabě",
        "hráč",
        "hračka",
        "hrad",
        "hradba",
        "Hradec",
        "hrana",
        "hraní",
        "hranice",
        "hrát",
        "hrdina",
        "hrdlo",
        "hrdý",
        "hrnec",
        "hrnek",
        "hrob",
        "hromada",
        "hromadný",
        "hrozba",
        "hrozit",
        "hrozně",
        "hrozný",
        "hrubý",
        "hruď",
        "hrůza",
        "hřbet",
        "hřbitov",
        "hřích",
        "hřiště",
        "hubený",
        "hudba",
        "hudební",
        "hudebník",
        "hůl",
        "humor",
        "hustota",
        "hustý",
        "hvězda",
        "hvězdný",
        "hýbat",
        "hypotéza",
        "chalupa",
        "chaos",
        "chápat",
        "charakter",
        "charakteristický",
        "charakteristika",
        "charakterizovat",
        "chata",
        "chemický",
        "chlad",
        "chladný",
        "chlap",
        "chlapec",
        "chlapík",
        "chléb",
        "chod",
        "chodba",
        "chodit",
        "chodník",
        "choroba",
        "chov",
        "chování",
        "chovat",
        "chrám",
        "chráněný",
        "chránit",
        "chtít",
        "chudák",
        "chudý",
        "chuť",
        "chutnat",
        "chůze",
        "chvět",
        "chvíle",
        "chvilka",
        "chyba",
        "chybět",
        "chybit",
        "chystat",
        "chytat",
        "chytit",
        "chytnout",
        "chytrý",
        "i",
        "idea",
        "ideál",
        "ideální",
        "identifikovat",
        "identita",
        "ignorovat",
        "ihned",
        "ikona",
        "iluze",
        "impuls",
        "in",
        "index",
        "indický",
        "Indie",
        "individuální",
        "infekce",
        "informace",
        "informační",
        "informovat",
        "infrastruktura",
        "Ing",
        "iniciativa",
        "inovace",
        "inscenace",
        "inspektor",
        "inspirace",
        "inspirovat",
        "instalace",
        "instituce",
        "institut",
        "integrace",
        "integrovaný",
        "inteligence",
        "inteligentní",
        "intenzita",
        "intenzivně",
        "intenzívní",
        "interakce",
        "interiér",
        "internet",
        "internetový",
        "interpretace",
        "interval",
        "investice",
        "investiční",
        "investor",
        "investovat",
        "inženýr",
        "IT",
        "Itálie",
        "italský",
        "izolace",
        "Izrael",
        "já",
        "jablko",
        "Jablonec",
        "jaderný",
        "jádro",
        "jak",
        "jakkoli",
        "jakmile",
        "jako",
        "jakoby",
        "jaksi",
        "Jakub",
        "jaký",
        "jakýkoli",
        "jakýsi",
        "jáma",
        "Japonsko",
        "japonský",
        "jarní",
        "jaro",
        "Jaromír",
        "Jaroslav",
        "jasně",
        "jasno",
        "jasný",
        "jazyk",
        "jazykový",
        "jed",
        "jeden",
        "jedenáct",
        "jedině",
        "jedinec",
        "jedinečný",
        "jediný",
        "jednak",
        "jednání",
        "jednat",
        "jednička",
        "jednoduchý",
        "jednoduše",
        "jednota",
        "jednotka",
        "jednotlivec",
        "jednotlivý",
        "jednotný",
        "jednou",
        "jednoznačně",
        "jednoznačný",
        "jeho",
        "její",
        "jejich",
        "jelikož",
        "jemně",
        "jemný",
        "jen",
        "jenom",
        "jenomže",
        "jenž",
        "jenže",
        "jeskyně",
        "jestli",
        "jestliže",
        "ještě",
        "jet",
        "jev",
        "jeviště",
        "jevit",
        "jezdec",
        "jezdit",
        "jezero",
        "Ježíš",
        "jídelna",
        "jídlo",
        "jih",
        "Jihlava",
        "jihočeský",
        "jinak",
        "jinam",
        "jinde",
        "jindy",
        "jiný",
        "jíst",
        "jistě",
        "jistota",
        "jistý",
        "jít",
        "jízda",
        "jízdní",
        "již",
        "jižní",
        "jméno",
        "jmenovaný",
        "jmenovat",
        "jo",
        "John",
        "k",
        "kabát",
        "kabel",
        "kabelka",
        "kabina",
        "kafe",
        "kalendář",
        "kalhoty",
        "kam",
        "kamarád",
        "kamarádka",
        "kámen",
        "kamenný",
        "kamera",
        "kamna",
        "kampaň",
        "Kanada",
        "kanál",
        "kancelář",
        "kandidát",
        "kapacita",
        "kapela",
        "kapitál",
        "kapitán",
        "kapitola",
        "kapka",
        "kaple",
        "kapsa",
        "kariéra",
        "karlovarský",
        "Karlův",
        "karta",
        "katastrofa",
        "kategorie",
        "Kateřina",
        "katolický",
        "kauza",
        "káva",
        "kavárna",
        "každodenní",
        "každopádně",
        "každoročně",
        "každý",
        "Kč",
        "kde",
        "kdepak",
        "kdesi",
        "kdo",
        "kdokoli",
        "kdosi",
        "kdy",
        "kdyby",
        "kdykoli",
        "kdysi",
        "když",
        "keř",
        "kg",
        "kilo",
        "kilogram",
        "kilometr",
        "kino",
        "Kladno",
        "kladný",
        "klasický",
        "klást",
        "klášter",
        "klávesnice",
        "klavír",
        "klec",
        "klepnout",
        "klesat",
        "klesnout",
        "klíč",
        "klíčový",
        "klid",
        "klidně",
        "klidný",
        "klient",
        "klika",
        "klima",
        "klín",
        "klinika",
        "klobouk",
        "kloub",
        "klub",
        "kluk",
        "km",
        "kmen",
        "kněz",
        "kniha",
        "knihovna",
        "kníže",
        "knížka",
        "koalice",
        "koberec",
        "kočka",
        "kód",
        "koláč",
        "kolečko",
        "kolega",
        "kolegyně",
        "kolej",
        "kolekce",
        "kolektivní",
        "kolem",
        "koleno",
        "kolik",
        "kolo",
        "kombinace",
        "kombinovat",
        "komedie",
        "komentář",
        "komentovat",
        "komerční",
        "komín",
        "komisař",
        "komise",
        "komora",
        "kompetence",
        "kompletní",
        "komplex",
        "komplexní",
        "komplikace",
        "komplikovaný",
        "komunální",
        "komunikace",
        "komunikační",
        "komunikovat",
        "komunista",
        "komunistický",
        "komunita",
        "konat",
        "koncentrace",
        "koncepce",
        "koncept",
        "koncert",
        "končetina",
        "končit",
        "konec",
        "koneckonců",
        "konečně",
        "konečný",
        "konference",
        "konflikt",
        "konkrétně",
        "konkrétní",
        "konkurence",
        "konkurenční",
        "konstatovat",
        "konstrukce",
        "kontakt",
        "kontext",
        "kontinent",
        "konto",
        "kontrola",
        "kontrolní",
        "kontrolovat",
        "konzervativní",
        "kopat",
        "kopec",
        "kopie",
        "koruna",
        "korupce",
        "kořen",
        "kořist",
        "kosmický",
        "kost",
        "kostel",
        "kostka",
        "kostým",
        "koš",
        "košile",
        "kotel",
        "kotník",
        "kouč",
        "koukat",
        "koule",
        "koupě",
        "koupelna",
        "koupit",
        "kouř",
        "kouřit",
        "kousek",
        "kout",
        "koutek",
        "kouzelný",
        "kouzlo",
        "kov",
        "kovový",
        "koza",
        "kožený",
        "krabice",
        "krabička",
        "kráčet",
        "krádež",
        "kraj",
        "krajina",
        "krajský",
        "král",
        "Králové",
        "královna",
        "královský",
        "království",
        "krása",
        "krásně",
        "krásný",
        "krást",
        "krátce",
        "krátký",
        "kráva",
        "krb",
        "krém",
        "kresba",
        "krev",
        "krevní",
        "Kristus",
        "kritérium",
        "kritický",
        "kritik",
        "kritika",
        "kritizovat",
        "krize",
        "krk",
        "krok",
        "kromě",
        "kroutit",
        "kroužek",
        "kruh",
        "kruhový",
        "krutý",
        "krvavý",
        "krystal",
        "kryt",
        "křehký",
        "křeslo",
        "křesťanský",
        "křičet",
        "křídlo",
        "křik",
        "křivka",
        "kříž",
        "křižovatka",
        "který",
        "kterýkoli",
        "kufr",
        "kuchyně",
        "kuchyňský",
        "kulatý",
        "kultura",
        "kulturní",
        "kůň",
        "kupovat",
        "kůra",
        "kurs",
        "kuře",
        "kus",
        "kůže",
        "kvalifikace",
        "kvalita",
        "kvalitní",
        "květ",
        "květen",
        "květina",
        "kvůli",
        "kyselina",
        "kyslík",
        "kývnout",
        "Labe",
        "laboratoř",
        "lahev",
        "láhev",
        "lákat",
        "lámat",
        "lampa",
        "lano",
        "láska",
        "laskavý",
        "látka",
        "lavice",
        "lavička",
        "lázně",
        "lebka",
        "léčba",
        "léčit",
        "led",
        "leden",
        "ledový",
        "legální",
        "legenda",
        "legendární",
        "legislativa",
        "legrace",
        "lehce",
        "lehký",
        "lehnout",
        "lék",
        "lékař",
        "lékařský",
        "Leonardo",
        "les",
        "lesklý",
        "lesní",
        "let",
        "letadlo",
        "létat",
        "letecký",
        "letět",
        "letiště",
        "letní",
        "léto",
        "letos",
        "letošní",
        "letoun",
        "lev",
        "levný",
        "levý",
        "lézt",
        "lež",
        "ležet",
        "ležící",
        "lhát",
        "lhůta",
        "li",
        "líbat",
        "Liberec",
        "liberecký",
        "líbit",
        "libovolný",
        "libra",
        "licence",
        "líčit",
        "lid",
        "lidový",
        "lídr",
        "lidský",
        "lidstvo",
        "liga",
        "likvidace",
        "limit",
        "lineární",
        "linie",
        "linka",
        "list",
        "lístek",
        "listí",
        "listina",
        "listopad",
        "lišit",
        "literární",
        "literatura",
        "líto",
        "litovat",
        "litr",
        "loď",
        "logicky",
        "logický",
        "logika",
        "lokalita",
        "lokální",
        "loket",
        "lom",
        "Londýn",
        "londýnský",
        "loňský",
        "louka",
        "lov",
        "lovec",
        "ložisko",
        "ložnice",
        "luxusní",
        "lůžko",
        "lze",
        "lžíce",
        "lžička",
        "m",
        "Maďarsko",
        "maďarský",
        "magický",
        "magistrát",
        "magnetický",
        "majetek",
        "majitel",
        "malba",
        "málem",
        "maličký",
        "malíř",
        "málo",
        "málokdo",
        "malovat",
        "malý",
        "máma",
        "maminka",
        "management",
        "manažer",
        "manipulace",
        "manžel",
        "manželka",
        "manželský",
        "manželství",
        "mapa",
        "marně",
        "masivní",
        "maska",
        "máslo",
        "maso",
        "masový",
        "matčin",
        "matematický",
        "matematika",
        "materiál",
        "mateřský",
        "matka",
        "mávat",
        "mávnout",
        "maximálně",
        "maximální",
        "maximum",
        "meč",
        "med",
        "medaile",
        "mediální",
        "medicína",
        "médium",
        "medvěd",
        "mechanický",
        "mechanismus",
        "měkký",
        "melodie",
        "měna",
        "méně",
        "měnit",
        "menu",
        "měření",
        "měřit",
        "měřítko",
        "měsíc",
        "měsíčně",
        "měsíční",
        "městečko",
        "město",
        "městský",
        "metoda",
        "metr",
        "metro",
        "metropole",
        "mez",
        "mezera",
        "mezi",
        "mezinárodní",
        "mezitím",
        "Microsoft",
        "míč",
        "míjet",
        "mil",
        "miláček",
        "milenec",
        "milenka",
        "miliarda",
        "milimetr",
        "milión",
        "milost",
        "milostný",
        "milovaný",
        "milovat",
        "milovník",
        "milý",
        "miminko",
        "mimo",
        "mimochodem",
        "mimořádně",
        "mimořádný",
        "mince",
        "minerál",
        "minerální",
        "minimálně",
        "minimální",
        "minimum",
        "ministerstvo",
        "ministr",
        "mínit",
        "minout",
        "minulost",
        "minulý",
        "minuta",
        "mír",
        "míra",
        "mírně",
        "mírný",
        "mířit",
        "mísa",
        "mise",
        "miska",
        "místní",
        "místnost",
        "místo",
        "místopředseda",
        "mistr",
        "mistrovství",
        "místy",
        "mít",
        "mívat",
        "mizet",
        "ml",
        "mládě",
        "mládež",
        "mládí",
        "mladík",
        "mladý",
        "mlčení",
        "mlčet",
        "mlčky",
        "mléčný",
        "mléko",
        "mlha",
        "mluvčí",
        "mluvit",
        "mlýn",
        "mnich",
        "mnohdy",
        "mnohem",
        "mnoho",
        "mnohokrát",
        "mnohý",
        "množství",
        "mobil",
        "mobilní",
        "moc",
        "moci",
        "mocný",
        "móda",
        "model",
        "modelka",
        "moderní",
        "modernizace",
        "modlit",
        "modlitba",
        "módní",
        "modrý",
        "modul",
        "mohutný",
        "mokrý",
        "molekula",
        "moment",
        "momentálně",
        "monitor",
        "morální",
        "Morava",
        "moravský",
        "moře",
        "mořský",
        "Moskva",
        "most",
        "motiv",
        "motivace",
        "motor",
        "motýl",
        "moudrý",
        "mouka",
        "mozek",
        "mozkový",
        "možná",
        "možnost",
        "možný",
        "mrak",
        "mráz",
        "mrtvola",
        "mrtvý",
        "mrzet",
        "mříž",
        "mše",
        "můj",
        "muset",
        "muzeum",
        "muzika",
        "muzikant",
        "muž",
        "mužský",
        "mužstvo",
        "my",
        "mýlit",
        "mysl",
        "myslet",
        "myš",
        "myšlení",
        "myšlenka",
        "mýtus",
        "mzda",
        "na",
        "nabídka",
        "nabídnout",
        "nabitý",
        "nabízet",
        "náboj",
        "náboženský",
        "náboženství",
        "nabrat",
        "nábytek",
        "náčelník",
        "nad",
        "nadace",
        "nadále",
        "nadávat",
        "nadechnout",
        "naděje",
        "nádherný",
        "nadchnout",
        "nádoba",
        "nádobí",
        "nádraží",
        "nádrž",
        "nadšení",
        "nadšený",
        "nahlas",
        "náhle",
        "nahlédnout",
        "náhlý",
        "náhoda",
        "náhodný",
        "náhodou",
        "nahoru",
        "nahoře",
        "náhrada",
        "nahradit",
        "náhradní",
        "nahrávka",
        "nahý",
        "nacházet",
        "najednou",
        "najevo",
        "najít",
        "náklad",
        "nakladatelství",
        "nákladní",
        "naklonit",
        "nakonec",
        "nakoupit",
        "nákup",
        "nákupní",
        "nakupovat",
        "nálada",
        "nález",
        "nalézt",
        "náležet",
        "nalít",
        "naložit",
        "námaha",
        "náměstek",
        "náměstí",
        "namísto",
        "namítnout",
        "nanejvýš",
        "naopak",
        "nápad",
        "napadat",
        "nápadně",
        "napadnout",
        "nápadný",
        "napětí",
        "nápis",
        "napít",
        "náplň",
        "naplnit",
        "naplno",
        "nápoj",
        "naposledy",
        "náprava",
        "naprosto",
        "naprostý",
        "naproti",
        "napřed",
        "napříč",
        "například",
        "napsat",
        "napůl",
        "narazit",
        "narážet",
        "náročný",
        "národ",
        "narodit",
        "národní",
        "nárok",
        "narození",
        "narozeniny",
        "náruč",
        "náručí",
        "nárůst",
        "narušit",
        "nařídit",
        "nařízení",
        "nasadit",
        "nasazení",
        "násilí",
        "náskok",
        "následek",
        "následně",
        "následný",
        "následovat",
        "následující",
        "naslouchat",
        "nastat",
        "nastavení",
        "nastavit",
        "nastoupit",
        "nástroj",
        "nástup",
        "nastupovat",
        "náš",
        "naštěstí",
        "natáčení",
        "natáčet",
        "natáhnout",
        "nato",
        "natočit",
        "natolik",
        "naučit",
        "navázat",
        "navazovat",
        "navíc",
        "návod",
        "návrat",
        "návrh",
        "navrhnout",
        "navrhovat",
        "návštěva",
        "návštěvník",
        "navštěvovat",
        "navštívit",
        "navzájem",
        "navzdory",
        "navždy",
        "název",
        "naznačit",
        "naznačovat",
        "náznak",
        "názor",
        "nazvaný",
        "nazvat",
        "nazývat",
        "ne",
        "nebe",
        "nebezpečí",
        "nebo",
        "neboli",
        "neboť",
        "něco",
        "nečekaně",
        "nečekaný",
        "nedaleko",
        "nedávno",
        "neděle",
        "nedělní",
        "nedostatek",
        "negativní",
        "nehet",
        "nehoda",
        "nechat",
        "nechávat",
        "nějak",
        "nějaký",
        "nejen",
        "nejenom",
        "nejenže",
        "nejistota",
        "nejprve",
        "někam",
        "někde",
        "někdejší",
        "někdo",
        "někdy",
        "několik",
        "několikrát",
        "některý",
        "Němec",
        "Německo",
        "německý",
        "nemoc",
        "nemocnice",
        "nemocný",
        "nemovitost",
        "nenávidět",
        "nenávist",
        "nepatrný",
        "nepochybně",
        "nepřátelský",
        "nepříliš",
        "nepřítel",
        "nerv",
        "nervový",
        "nervózní",
        "nesmírně",
        "nesmysl",
        "nést",
        "neštěstí",
        "neustále",
        "neustálý",
        "neuvěřitelný",
        "nevinný",
        "nevýhoda",
        "new",
        "nezaměstnanost",
        "nezávislost",
        "nezbytný",
        "než",
        "NHL",
        "nic",
        "nicméně",
        "ničit",
        "nijak",
        "nikam",
        "nikde",
        "nikdo",
        "nikdy",
        "nikoli",
        "nitro",
        "nízko",
        "nízký",
        "no",
        "noc",
        "noční",
        "noha",
        "norma",
        "normálně",
        "normální",
        "nos",
        "nosit",
        "nositel",
        "nosný",
        "notebook",
        "nouze",
        "nováček",
        "nově",
        "novela",
        "novinář",
        "novinka",
        "noviny",
        "nový",
        "nula",
        "nulový",
        "nutit",
        "nutně",
        "nutnost",
        "nutný",
        "nůž",
        "nýbrž",
        "Nymburk",
        "nyní",
        "o",
        "oba",
        "obal",
        "obálka",
        "obava",
        "obávat",
        "občan",
        "občanský",
        "občas",
        "obdivovat",
        "období",
        "obdobný",
        "obdržet",
        "obec",
        "obecně",
        "obecní",
        "obecný",
        "oběd",
        "obejít",
        "obejmout",
        "oběť",
        "obchod",
        "obchodní",
        "obchodník",
        "objednat",
        "objekt",
        "objektivní",
        "objem",
        "objev",
        "objevit",
        "objevovat",
        "oblak",
        "oblast",
        "oblečení",
        "oblečený",
        "oblek",
        "obléknout",
        "obliba",
        "oblíbený",
        "obličej",
        "obloha",
        "oblouk",
        "obnova",
        "obnovit",
        "obočí",
        "obojí",
        "obor",
        "obr",
        "obracet",
        "obrana",
        "obránce",
        "obrat",
        "obrátit",
        "obraz",
        "obrázek",
        "obrazovka",
        "obrovský",
        "obřad",
        "obří",
        "obsadit",
        "obsah",
        "obsahovat",
        "obsahující",
        "obsluha",
        "obtěžovat",
        "obtíž",
        "obtížně",
        "obtížný",
        "obvinění",
        "obvinit",
        "obvod",
        "obvykle",
        "obvyklý",
        "obyčejně",
        "obyčejný",
        "obytný",
        "obývací",
        "obývák",
        "obyvatel",
        "obyvatelstvo",
        "obzor",
        "obzvlášť",
        "ocas",
        "oceán",
        "ocel",
        "ocelový",
        "ocenění",
        "ocenit",
        "ocitnout",
        "očekávání",
        "očekávaný",
        "očekávat",
        "očividně",
        "oční",
        "od",
        "odbor",
        "odborník",
        "odborný",
        "oddělení",
        "oddělit",
        "oddíl",
        "odebrat",
        "odehrát",
        "odehrávat",
        "odejít",
        "oděv",
        "odhad",
        "odhadnout",
        "odhadovat",
        "odhalit",
        "odcházet",
        "odchod",
        "odjet",
        "odjezd",
        "odjíždět",
        "odkaz",
        "odkud",
        "odlišný",
        "odložit",
        "odměna",
        "odmítat",
        "odmítnout",
        "odmlčet",
        "odnést",
        "odolnost",
        "odolný",
        "odpad",
        "odpočinek",
        "odpočinout",
        "odpočívat",
        "odpoledne",
        "odpor",
        "odpověď",
        "odpovědět",
        "odpovědnost",
        "odpovědný",
        "odpovídající",
        "odpovídat",
        "odpustit",
        "odraz",
        "odrážet",
        "odrůda",
        "ODS",
        "odsoudit",
        "odst",
        "odstartovat",
        "odstín",
        "odstranění",
        "odstranit",
        "odstup",
        "odsud",
        "odtáhnout",
        "odtud",
        "odvaha",
        "odvážit",
        "odvážný",
        "odvést",
        "odvětit",
        "odvětví",
        "odvézt",
        "odvolání",
        "odvolat",
        "odvrátit",
        "of",
        "oficiálně",
        "oficiální",
        "oheň",
        "ohlásit",
        "ohled",
        "ohledně",
        "ohlédnout",
        "ohromný",
        "ohrozit",
        "ohrožení",
        "ohrožený",
        "ohrožovat",
        "ochotně",
        "ochotný",
        "ochrana",
        "ochránit",
        "ochranný",
        "okamžik",
        "okamžitě",
        "okamžitý",
        "okénko",
        "okno",
        "oko",
        "okolí",
        "okolní",
        "okolnost",
        "okolo",
        "okraj",
        "okres",
        "okresní",
        "okruh",
        "olej",
        "Olomouc",
        "olomoucký",
        "oltář",
        "olympiáda",
        "olympijský",
        "omáčka",
        "omezení",
        "omezený",
        "omezit",
        "omezovat",
        "omlouvat",
        "omluvit",
        "omyl",
        "on",
        "onemocnění",
        "onen",
        "oni",
        "opačný",
        "opak",
        "opakovaně",
        "opakovaný",
        "opakovat",
        "opatrně",
        "opatrný",
        "opatření",
        "opatřit",
        "opera",
        "operace",
        "operační",
        "operátor",
        "opět",
        "opilý",
        "opírat",
        "opora",
        "opouštět",
        "opozice",
        "oprava",
        "opravdový",
        "opravdu",
        "opravit",
        "oprávněný",
        "oproti",
        "opřít",
        "optický",
        "optimální",
        "opustit",
        "opuštěný",
        "oranžový",
        "ordinace",
        "orgán",
        "organický",
        "organismus",
        "organizace",
        "organizační",
        "organizátor",
        "organizovaný",
        "organizovat",
        "orchestr",
        "orientace",
        "orientovat",
        "originál",
        "originální",
        "osa",
        "osada",
        "osamělý",
        "oslava",
        "oslavit",
        "oslovit",
        "osm",
        "osmdesát",
        "osmdesátý",
        "osmnáct",
        "osmý",
        "osoba",
        "osobně",
        "osobní",
        "osobnost",
        "ostatně",
        "ostatní",
        "Ostrava",
        "ostravský",
        "ostrov",
        "ostrý",
        "ostře",
        "osud",
        "osvětlení",
        "ošklivý",
        "otáčet",
        "otázka",
        "otcův",
        "otec",
        "otevírat",
        "otevřeně",
        "otevření",
        "otevřený",
        "otevřít",
        "otisk",
        "otočit",
        "otřást",
        "otřít",
        "otvírat",
        "otvor",
        "ovce",
        "Ove",
        "ověřit",
        "ovládání",
        "ovládat",
        "ovládnout",
        "ovlivnit",
        "ovlivňovat",
        "ovoce",
        "ovocný",
        "ovšem",
        "oxid",
        "označení",
        "označit",
        "označovat",
        "oznámení",
        "oznámit",
        "ozvat",
        "ozývat",
        "oženit",
        "pacient",
        "pád",
        "padat",
        "padesát",
        "padesátý",
        "padnout",
        "pach",
        "pachatel",
        "pak",
        "palác",
        "palec",
        "pálit",
        "palivo",
        "paluba",
        "památka",
        "pamatovat",
        "paměť",
        "pan",
        "pán",
        "panel",
        "panenka",
        "pánev",
        "paní",
        "panika",
        "panna",
        "panovat",
        "papež",
        "papír",
        "papírový",
        "paprsek",
        "pár",
        "pára",
        "parametr",
        "Pardubice",
        "pardubický",
        "park",
        "parkoviště",
        "parlament",
        "parlamentní",
        "parta",
        "partie",
        "partner",
        "Paříž",
        "pas",
        "pás",
        "pasivní",
        "páska",
        "pásmo",
        "past",
        "pata",
        "pátek",
        "patnáct",
        "pátrat",
        "patrně",
        "patrný",
        "patro",
        "patřit",
        "pátý",
        "pauza",
        "paže",
        "péci",
        "péče",
        "pečlivě",
        "pečovat",
        "pedagog",
        "pedagogický",
        "peklo",
        "pěkně",
        "pěkný",
        "pěna",
        "peněženka",
        "peníze",
        "pepř",
        "pero",
        "personál",
        "perspektiva",
        "pes",
        "pěst",
        "pěstování",
        "pěstovat",
        "pestrý",
        "pěšky",
        "pět",
        "Petr",
        "pevně",
        "pevnost",
        "pevný",
        "pilíř",
        "pilot",
        "písek",
        "písemný",
        "píseň",
        "pískovec",
        "písmeno",
        "písmo",
        "písnička",
        "pistole",
        "pít",
        "pití",
        "pivo",
        "pivovar",
        "placený",
        "pláč",
        "plakat",
        "plamen",
        "plán",
        "planeta",
        "plánování",
        "plánovaný",
        "plánovat",
        "plast",
        "plastový",
        "plášť",
        "plat",
        "platba",
        "plátek",
        "platforma",
        "platit",
        "plátno",
        "platnost",
        "platný",
        "plavat",
        "play",
        "pláž",
        "plech",
        "plést",
        "pleť",
        "plíce",
        "plně",
        "plnění",
        "plnit",
        "plný",
        "plod",
        "plocha",
        "plochý",
        "plošina",
        "plot",
        "plukovník",
        "plus",
        "plyn",
        "plynout",
        "plynový",
        "Plzeň",
        "plzeňský",
        "pneumatika",
        "po",
        "poblíž",
        "pobočka",
        "pobřeží",
        "pobyt",
        "pocit",
        "pocítit",
        "pociťovat",
        "počasí",
        "počáteční",
        "počátek",
        "počet",
        "početný",
        "počítač",
        "počítačový",
        "počítat",
        "počkat",
        "pod",
        "podání",
        "podařit",
        "podat",
        "podávat",
        "poděkovat",
        "podél",
        "podepsat",
        "podezřelý",
        "podezření",
        "podíl",
        "podílet",
        "pódium",
        "podívat",
        "podivný",
        "podklad",
        "podlaha",
        "podle",
        "podléhat",
        "podlehnout",
        "podmínka",
        "podnět",
        "podnik",
        "podnikání",
        "podnikat",
        "podnikatel",
        "podnikatelský",
        "podoba",
        "podobat",
        "podobně",
        "podobný",
        "podotknout",
        "podpis",
        "podpora",
        "podporovat",
        "podpořit",
        "podrobně",
        "podrobnost",
        "podrobný",
        "podruhé",
        "podstata",
        "podstatně",
        "podstatný",
        "podvod",
        "podzemní",
        "podzim",
        "podzimní",
        "poezie",
        "pohádka",
        "pohár",
        "pohladit",
        "pohlaví",
        "pohled",
        "pohlédnout",
        "pohnout",
        "pohoda",
        "pohodlně",
        "pohodlný",
        "pohon",
        "pohovka",
        "pohřeb",
        "pohyb",
        "pohybovat",
        "pohybový",
        "pocházet",
        "pochod",
        "pochopení",
        "pochopit",
        "pochopitelně",
        "pochopitelný",
        "pochyba",
        "pochybnost",
        "pochybovat",
        "pojem",
        "pojetí",
        "pojištění",
        "pojišťovna",
        "pojmenovat",
        "pokaždé",
        "poklad",
        "pokládat",
        "pokles",
        "pokoj",
        "pokoušet",
        "pokožka",
        "pokračování",
        "pokračovat",
        "pokrčit",
        "pokročilý",
        "pokrok",
        "pokrýt",
        "pokrytý",
        "pokrývat",
        "pokud",
        "pokus",
        "pokusit",
        "pokuta",
        "pokyn",
        "Polák",
        "pole",
        "poledne",
        "polévka",
        "polibek",
        "políbit",
        "police",
        "policejní",
        "policie",
        "policista",
        "politický",
        "politik",
        "politika",
        "polní",
        "poločas",
        "poloha",
        "polovina",
        "položený",
        "položit",
        "položka",
        "Polsko",
        "polský",
        "polštář",
        "pomáhat",
        "pomalu",
        "pomalý",
        "poměr",
        "poměrně",
        "poměry",
        "pomoc",
        "pomoci",
        "pomocí",
        "pomocník",
        "pomůcka",
        "pomyslet",
        "pondělí",
        "ponechat",
        "poněkud",
        "poněvadž",
        "ponořit",
        "popadnout",
        "popel",
        "popis",
        "popisovat",
        "poplatek",
        "poprvé",
        "popsaný",
        "popsat",
        "poptávka",
        "populace",
        "populární",
        "poradce",
        "poradit",
        "porazit",
        "porážka",
        "porce",
        "porod",
        "porost",
        "porovnání",
        "porozumět",
        "portál",
        "portrét",
        "porucha",
        "porušení",
        "pořad",
        "pořád",
        "pořádat",
        "pořadatel",
        "pořádek",
        "pořadí",
        "pořádně",
        "pořádný",
        "pořídit",
        "posadit",
        "posádka",
        "posílat",
        "posílit",
        "posilovat",
        "poskytnout",
        "poskytovat",
        "poslanec",
        "poslanecký",
        "poslání",
        "poslat",
        "poslední",
        "poslechnout",
        "posléze",
        "poslouchat",
        "posloužit",
        "posluchač",
        "posoudit",
        "post",
        "postarat",
        "postava",
        "postavení",
        "postavený",
        "postavit",
        "postel",
        "postihnout",
        "postižení",
        "postižený",
        "postoj",
        "postoupit",
        "postrádat",
        "postup",
        "postupně",
        "postupný",
        "postupovat",
        "posun",
        "posunout",
        "posvátný",
        "poškodit",
        "poškození",
        "poškozený",
        "pošta",
        "pot",
        "poté",
        "potenciál",
        "potenciální",
        "potěšení",
        "potěšit",
        "potíž",
        "potkat",
        "potlačit",
        "potok",
        "potom",
        "potomek",
        "potrava",
        "potravina",
        "potrestat",
        "potřeba",
        "potřebný",
        "potřebovat",
        "potvrdit",
        "potvrzovat",
        "pouhý",
        "poušť",
        "pouštět",
        "pouť",
        "pouto",
        "pouzdro",
        "pouze",
        "použít",
        "použití",
        "použitý",
        "používání",
        "používaný",
        "používat",
        "povaha",
        "považovat",
        "povědět",
        "povést",
        "pověst",
        "povídat",
        "povídka",
        "povinnost",
        "povinný",
        "povodeň",
        "povolání",
        "povolení",
        "povolit",
        "povrch",
        "povrchový",
        "povzdechnout",
        "pozadí",
        "pozdě",
        "pozdní",
        "pozdrav",
        "pozdravit",
        "pozemek",
        "pozice",
        "pozitivní",
        "poznamenat",
        "poznámka",
        "poznání",
        "poznat",
        "poznatek",
        "poznávat",
        "pozor",
        "pozorně",
        "pozornost",
        "pozorování",
        "pozorovat",
        "pozoruhodný",
        "pozvat",
        "požádat",
        "požadavek",
        "požadovaný",
        "požadovat",
        "požár",
        "práce",
        "pracovat",
        "pracoviště",
        "pracovna",
        "pracovní",
        "pracovník",
        "pracující",
        "prádlo",
        "práh",
        "Praha",
        "prach",
        "prakticky",
        "praktický",
        "pramen",
        "prase",
        "prášek",
        "prát",
        "pravda",
        "pravděpodobně",
        "pravděpodobnost",
        "pravděpodobný",
        "pravdivý",
        "právě",
        "pravidelně",
        "pravidelný",
        "pravidlo",
        "pravit",
        "právní",
        "právnický",
        "právník",
        "právo",
        "pravomoc",
        "pravý",
        "praxe",
        "prázdniny",
        "prázdný",
        "pražský",
        "prdel",
        "premiér",
        "premiéra",
        "prestižní",
        "prevence",
        "prezentace",
        "prezentovat",
        "prezident",
        "prezidentský",
        "primární",
        "primátor",
        "princ",
        "princezna",
        "princip",
        "priorita",
        "prkno",
        "pro",
        "proběhnout",
        "probíhat",
        "probírat",
        "problém",
        "problematický",
        "problematika",
        "proboha",
        "probrat",
        "probudit",
        "procento",
        "proces",
        "procesor",
        "proč",
        "prodat",
        "prodávat",
        "prodej",
        "prodejce",
        "prodejna",
        "prodloužení",
        "prodloužit",
        "producent",
        "produkce",
        "produkovat",
        "produkt",
        "profese",
        "profesionální",
        "profesní",
        "profesor",
        "profil",
        "program",
        "prohlásit",
        "prohlášení",
        "prohlédnout",
        "prohlídka",
        "prohlížet",
        "prohodit",
        "prohrát",
        "procházet",
        "procházka",
        "projekt",
        "projektový",
        "projet",
        "projev",
        "projevit",
        "projevovat",
        "projít",
        "projíždět",
        "prokázat",
        "proměna",
        "proměnit",
        "prominout",
        "promluvit",
        "pronásledovat",
        "pronést",
        "pronikat",
        "proniknout",
        "propadnout",
        "propast",
        "propojení",
        "propojit",
        "propustit",
        "prosadit",
        "prosazovat",
        "prosinec",
        "prosit",
        "proslulý",
        "prospěch",
        "prostě",
        "Prostějov",
        "prostor",
        "prostora",
        "prostorový",
        "prostředek",
        "prostředí",
        "prostřednictvím",
        "prostý",
        "protáhnout",
        "protein",
        "protest",
        "protestovat",
        "proti",
        "protivník",
        "proto",
        "protokol",
        "protože",
        "proud",
        "provádět",
        "provázet",
        "provedení",
        "provedený",
        "provést",
        "provoz",
        "provozní",
        "provozovat",
        "provozovatel",
        "prozatím",
        "prozradit",
        "prozrazovat",
        "prožít",
        "prožívat",
        "prsa",
        "prst",
        "prsten",
        "pršet",
        "průběh",
        "prudce",
        "prudký",
        "pruh",
        "průhledný",
        "průkaz",
        "průměr",
        "průměrný",
        "průmysl",
        "průmyslový",
        "průvod",
        "průvodce",
        "průzkum",
        "prvek",
        "první",
        "prvý",
        "prý",
        "pryč",
        "přání",
        "přát",
        "přátelský",
        "přátelství",
        "přece",
        "přečíst",
        "před",
        "předat",
        "předávat",
        "předek",
        "předem",
        "především",
        "předcházet",
        "předchozí",
        "předchůdce",
        "předložit",
        "předmět",
        "přednáška",
        "přední",
        "přednost",
        "předpis",
        "předpoklad",
        "předpokládat",
        "předseda",
        "představa",
        "představení",
        "představenstvo",
        "představit",
        "představitel",
        "představovat",
        "předstírat",
        "předtím",
        "předvádět",
        "předvést",
        "přehled",
        "přehledný",
        "přehlídka",
        "přehrávač",
        "přecházet",
        "přechod",
        "přejet",
        "přejít",
        "překážka",
        "překlad",
        "překonat",
        "překročit",
        "překvapení",
        "překvapit",
        "překvapivě",
        "překvapivý",
        "přelom",
        "přeložit",
        "přemýšlet",
        "přenášet",
        "přenést",
        "přenos",
        "přeprava",
        "přerušit",
        "přes",
        "přesně",
        "přesnost",
        "přesný",
        "přestat",
        "přestávat",
        "přestávka",
        "přestěhovat",
        "přesto",
        "přestože",
        "přesunout",
        "přesvědčení",
        "přesvědčený",
        "přesvědčit",
        "převážně",
        "převést",
        "převod",
        "převzít",
        "přežít",
        "při",
        "příběh",
        "přiblížit",
        "přibližně",
        "přibližovat",
        "příbuzný",
        "přibýt",
        "přibývat",
        "přičemž",
        "příčina",
        "příčka",
        "přidat",
        "přidávat",
        "přihlásit",
        "přihodit",
        "přicházet",
        "příchod",
        "přijatelný",
        "příjem",
        "příjemně",
        "příjemný",
        "přijet",
        "přijetí",
        "příjezd",
        "přijímat",
        "přijít",
        "přijmout",
        "příkaz",
        "příklad",
        "přikývnout",
        "příležitost",
        "příliš",
        "příloha",
        "přiložit",
        "přiměřený",
        "přimět",
        "přímo",
        "přímý",
        "přinášet",
        "přinejmenším",
        "přinést",
        "přínos",
        "přinutit",
        "případ",
        "připadat",
        "případně",
        "případný",
        "připojení",
        "připojit",
        "připomenout",
        "připomínající",
        "připomínat",
        "připouštět",
        "příprava",
        "přípravek",
        "připravený",
        "připravit",
        "připravovat",
        "připsat",
        "připustit",
        "příroda",
        "přírodní",
        "přirozeně",
        "přirozený",
        "příslušník",
        "příslušný",
        "přísně",
        "přísný",
        "přispět",
        "příspěvek",
        "přispívat",
        "přistát",
        "přístav",
        "přistoupit",
        "přístroj",
        "přístup",
        "přístupný",
        "přistupovat",
        "příšerný",
        "příště",
        "příští",
        "přitáhnout",
        "přitahovat",
        "přítel",
        "přítelkyně",
        "přitisknout",
        "přitom",
        "přítomnost",
        "přítomný",
        "přivést",
        "přivézt",
        "přivítat",
        "přízemí",
        "příznak",
        "přiznat",
        "přiznávat",
        "příznivec",
        "příznivý",
        "přizpůsobit",
        "psací",
        "psaní",
        "psaný",
        "psát",
        "psí",
        "psychický",
        "psycholog",
        "psychologický",
        "psychologie",
        "ptačí",
        "pták",
        "ptát",
        "publikace",
        "publikovat",
        "publikum",
        "půda",
        "půjčit",
        "půjčka",
        "půl",
        "půle",
        "půlka",
        "půlnoc",
        "pult",
        "pusa",
        "působení",
        "působící",
        "působit",
        "pustit",
        "puška",
        "putovat",
        "původ",
        "původně",
        "původní",
        "pyšný",
        "pytel",
        "rád",
        "rada",
        "radikální",
        "rádio",
        "radit",
        "radní",
        "radnice",
        "radost",
        "radovat",
        "ráj",
        "raketa",
        "rakev",
        "Rakousko",
        "rakouský",
        "rakovina",
        "rám",
        "rámec",
        "rameno",
        "rána",
        "ranní",
        "ráno",
        "raný",
        "ráz",
        "rázem",
        "reagovat",
        "reakce",
        "realita",
        "realizace",
        "realizovat",
        "reálný",
        "recept",
        "red",
        "redakce",
        "redaktor",
        "reforma",
        "region",
        "regionální",
        "regulace",
        "reklama",
        "reklamní",
        "rekonstrukce",
        "rekord",
        "relativně",
        "relativní",
        "reprezentace",
        "reprezentant",
        "reprezentovat",
        "republika",
        "resp",
        "respekt",
        "respektive",
        "respektovat",
        "respondent",
        "restaurace",
        "ret",
        "revoluce",
        "revoluční",
        "rezerva",
        "režie",
        "režim",
        "režisér",
        "riskovat",
        "rituál",
        "riziko",
        "rizikový",
        "robot",
        "ročně",
        "roční",
        "ročník",
        "rod",
        "rodič",
        "rodina",
        "rodinný",
        "rodit",
        "rodný",
        "roh",
        "rok",
        "role",
        "román",
        "romantický",
        "ropa",
        "rostlina",
        "rostlinný",
        "rostoucí",
        "rovina",
        "rovněž",
        "rovnice",
        "rovnou",
        "rovnováha",
        "rovný",
        "rozběhnout",
        "rozbít",
        "rozbitý",
        "rozdělení",
        "rozdělit",
        "rozdíl",
        "rozdílný",
        "rozesmát",
        "rozeznat",
        "rozhlas",
        "rozhlédnout",
        "rozhlížet",
        "rozhodčí",
        "rozhodně",
        "rozhodnout",
        "rozhodnutí",
        "rozhodování",
        "rozhodovat",
        "rozhodující",
        "rozhovor",
        "rozhraní",
        "rozjet",
        "rozkaz",
        "rozlehlý",
        "rozlišení",
        "rozlišovat",
        "rozloučit",
        "rozložit",
        "rozměr",
        "rozpaky",
        "rozpočet",
        "rozpor",
        "rozpoznat",
        "rozsah",
        "rozsáhlý",
        "rozsudek",
        "rozsvítit",
        "rozšíření",
        "rozšířený",
        "rozšířit",
        "rozšiřovat",
        "roztok",
        "rozum",
        "rozumět",
        "rozumný",
        "rozvíjet",
        "rozvod",
        "rozvoj",
        "ručně",
        "ruční",
        "rudý",
        "ruch",
        "ruka",
        "rukáv",
        "rukavice",
        "rukopis",
        "Rus",
        "Rusko",
        "ruský",
        "růst",
        "rušit",
        "různě",
        "různý",
        "růže",
        "růžový",
        "ryba",
        "rybník",
        "rychle",
        "rychlost",
        "rychlý",
        "rys",
        "rytíř",
        "rytmus",
        "rýže",
        "řád",
        "řada",
        "řádek",
        "řadit",
        "řádný",
        "řasa",
        "Řecko",
        "řecký",
        "řeč",
        "ředitel",
        "ředitelka",
        "řeka",
        "řemeslo",
        "řešení",
        "řešit",
        "řetěz",
        "řetězec",
        "řez",
        "říci",
        "řídicí",
        "řidič",
        "řídit",
        "říjen",
        "říkat",
        "Řím",
        "římský",
        "říše",
        "řízení",
        "řízený",
        "řvát",
        "s",
        "sáček",
        "sad",
        "sahat",
        "sáhnout",
        "sako",
        "sakra",
        "sál",
        "salát",
        "salón",
        "sám",
        "samec",
        "samostatně",
        "samostatný",
        "samota",
        "samotný",
        "samozřejmě",
        "samozřejmost",
        "Samsung",
        "samý",
        "sankce",
        "sazba",
        "sázet",
        "sběr",
        "sbírat",
        "sbírka",
        "sbor",
        "scéna",
        "scénář",
        "sdělení",
        "sdělit",
        "sdílet",
        "sdružení",
        "se",
        "sebevědomí",
        "sebevražda",
        "sebrat",
        "sedadlo",
        "sedět",
        "sedm",
        "sedmdesát",
        "sedmdesátý",
        "sedmnáct",
        "sedmý",
        "sednout",
        "segment",
        "sehnat",
        "sehrát",
        "sejít",
        "sekce",
        "sektor",
        "sekunda",
        "sekvence",
        "selhání",
        "sem",
        "semeno",
        "seminář",
        "sen",
        "senát",
        "senátor",
        "senior",
        "seriál",
        "série",
        "server",
        "servis",
        "sestava",
        "sestavit",
        "sestra",
        "setkání",
        "setkat",
        "setkávat",
        "sever",
        "severní",
        "sevřít",
        "sex",
        "sexuální",
        "seznam",
        "seznámit",
        "sezona",
        "sezóna",
        "sféra",
        "shánět",
        "shoda",
        "shodnout",
        "show",
        "shrnout",
        "shromáždění",
        "scházet",
        "schéma",
        "schod",
        "schodiště",
        "schopnost",
        "schopný",
        "schovat",
        "schovávat",
        "schránka",
        "schůzka",
        "schválit",
        "sice",
        "sídliště",
        "sídlit",
        "sídlo",
        "signál",
        "síla",
        "silně",
        "silnice",
        "silniční",
        "silný",
        "síň",
        "síť",
        "situace",
        "skákat",
        "skála",
        "skalní",
        "skandál",
        "sklad",
        "skládat",
        "skladatel",
        "skladba",
        "skleněný",
        "sklenice",
        "sklenička",
        "sklenka",
        "sklep",
        "sklo",
        "sklon",
        "sklonit",
        "skočit",
        "skok",
        "skončení",
        "skončit",
        "skoro",
        "skromný",
        "skrýt",
        "skrytý",
        "skrývat",
        "skrz",
        "skříň",
        "skříňka",
        "skupina",
        "skupinka",
        "skutečně",
        "skutečnost",
        "skutečný",
        "skvěle",
        "skvělý",
        "skvrna",
        "slabost",
        "slabý",
        "sladký",
        "sláva",
        "Slavia",
        "slavit",
        "slavnost",
        "slavnostní",
        "slavný",
        "slečna",
        "sledování",
        "sledovaný",
        "sledovat",
        "slepý",
        "sleva",
        "slib",
        "slíbit",
        "slibovat",
        "sloup",
        "sloužit",
        "Slovensko",
        "slovenský",
        "slovní",
        "slovník",
        "slovo",
        "složení",
        "složený",
        "složit",
        "složitý",
        "složka",
        "sluchátko",
        "slunce",
        "sluneční",
        "slušet",
        "slušný",
        "služba",
        "slyšet",
        "slza",
        "smát",
        "směr",
        "směřovat",
        "směs",
        "směšný",
        "smět",
        "smích",
        "smířit",
        "smíšený",
        "smlouva",
        "smrt",
        "smrtelný",
        "smůla",
        "smutek",
        "smutný",
        "smysl",
        "snad",
        "snadno",
        "snadný",
        "snaha",
        "snášet",
        "snažit",
        "sněhový",
        "sněmovna",
        "snést",
        "snídaně",
        "sníh",
        "snímek",
        "sníst",
        "snít",
        "snížení",
        "snížit",
        "snižovat",
        "sobota",
        "Sobotka",
        "sobotní",
        "socialistický",
        "sociální",
        "software",
        "socha",
        "solární",
        "sotva",
        "souboj",
        "soubor",
        "současně",
        "současnost",
        "současný",
        "součást",
        "soud",
        "soudce",
        "soudit",
        "soudní",
        "soudruh",
        "souhlas",
        "souhlasit",
        "soukromí",
        "soukromý",
        "soulad",
        "soupeř",
        "sourozenec",
        "soused",
        "sousední",
        "soustava",
        "soustředění",
        "soustředit",
        "soutěž",
        "související",
        "souviset",
        "souvislost",
        "sovětský",
        "spadat",
        "spadnout",
        "spáchat",
        "spánek",
        "Sparta",
        "spát",
        "spatřit",
        "specialista",
        "specializovaný",
        "speciálně",
        "speciální",
        "specifický",
        "spěchat",
        "spektrum",
        "spis",
        "spisovatel",
        "spíš",
        "spíše",
        "splnit",
        "splňovat",
        "spočítat",
        "spočívat",
        "spodní",
        "spoj",
        "spojenec",
        "spojení",
        "spojený",
        "spojit",
        "spojovat",
        "spokojeně",
        "spokojenost",
        "spokojený",
        "společenský",
        "společenství",
        "společně",
        "společník",
        "společnost",
        "společný",
        "spoléhat",
        "spolehlivý",
        "spolek",
        "spolu",
        "spolupráce",
        "spolupracovat",
        "spolupracovník",
        "spolužák",
        "spor",
        "sport",
        "sportovec",
        "sportovní",
        "spotřeba",
        "spotřebitel",
        "spousta",
        "správa",
        "správce",
        "spravedlivý",
        "spravedlnost",
        "správně",
        "správní",
        "správný",
        "sprcha",
        "spustit",
        "srazit",
        "srážka",
        "srdce",
        "srdeční",
        "srovnání",
        "srovnat",
        "srovnatelný",
        "srpen",
        "stabilita",
        "stabilní",
        "stačit",
        "stadión",
        "stadium",
        "stáhnout",
        "stahovat",
        "stáj",
        "stále",
        "stálý",
        "stan",
        "standard",
        "standardní",
        "stánek",
        "stanice",
        "stanovení",
        "stanovený",
        "stanovisko",
        "stanoviště",
        "stanovit",
        "starat",
        "starost",
        "starosta",
        "start",
        "starý",
        "stařec",
        "stáří",
        "stát",
        "statek",
        "statistický",
        "statistika",
        "státní",
        "stav",
        "stávající",
        "stávat",
        "stavba",
        "stavební",
        "stavět",
        "stavit",
        "stehno",
        "stejně",
        "stejný",
        "stěna",
        "stezka",
        "stěží",
        "stěžovat",
        "stihnout",
        "stín",
        "stisknout",
        "stížnost",
        "sto",
        "stojící",
        "stolek",
        "století",
        "stopa",
        "stoupat",
        "stoupnout",
        "stovka",
        "str",
        "strach",
        "strana",
        "stranický",
        "stránka",
        "stranou",
        "strašně",
        "strašný",
        "strategický",
        "strategie",
        "strava",
        "strávit",
        "strážce",
        "strážník",
        "strčit",
        "stres",
        "strhnout",
        "stroj",
        "strom",
        "strop",
        "struktura",
        "strýc",
        "strýček",
        "střed",
        "středa",
        "středisko",
        "středně",
        "střední",
        "středověký",
        "střecha",
        "střela",
        "střelec",
        "střešní",
        "střet",
        "stříbrný",
        "stříbro",
        "střídat",
        "střílet",
        "student",
        "studený",
        "studie",
        "studijní",
        "studium",
        "studovat",
        "stůl",
        "stupeň",
        "stydět",
        "styk",
        "styl",
        "subjekt",
        "sucho",
        "suchý",
        "sukně",
        "sůl",
        "suma",
        "sundat",
        "super",
        "surovina",
        "sv",
        "svah",
        "sval",
        "svatba",
        "svatební",
        "svátek",
        "svatý",
        "svaz",
        "svazek",
        "svědčit",
        "svědectví",
        "svědek",
        "svědomí",
        "svěřit",
        "svět",
        "světelný",
        "světle",
        "světlo",
        "světlý",
        "světový",
        "svetr",
        "svíčka",
        "svírat",
        "svítit",
        "svoboda",
        "Svoboda",
        "svobodný",
        "svůj",
        "symbol",
        "symbolický",
        "sympatický",
        "syn",
        "sýr",
        "systém",
        "šálek",
        "šampionát",
        "šance",
        "šatna",
        "šaty",
        "šedesát",
        "šedesátý",
        "šedivý",
        "šedý",
        "šéf",
        "šeptat",
        "šest",
        "šestnáct",
        "šestý",
        "šetření",
        "šetřit",
        "šikovný",
        "šílený",
        "široký",
        "šíření",
        "šířit",
        "šířka",
        "škála",
        "škoda",
        "Škoda",
        "škola",
        "školka",
        "školní",
        "školství",
        "šok",
        "Španělsko",
        "španělský",
        "špatně",
        "špatný",
        "šperk",
        "špička",
        "špičkový",
        "špinavý",
        "štáb",
        "šťastně",
        "šťastný",
        "šťáva",
        "štědrý",
        "štěstí",
        "štíhlý",
        "štít",
        "Švédsko",
        "švédský",
        "Švýcarsko",
        "švýcarský",
        "tableta",
        "tábor",
        "tabule",
        "tabulka",
        "tady",
        "tah",
        "tahat",
        "táhnout",
        "tajemník",
        "tajemný",
        "tajemství",
        "tajit",
        "tajný",
        "tak",
        "také",
        "takhle",
        "takový",
        "takovýto",
        "takřka",
        "takto",
        "taky",
        "takzvaný",
        "takže",
        "talent",
        "talíř",
        "tam",
        "tamní",
        "tančit",
        "tanec",
        "taneční",
        "tank",
        "taška",
        "táta",
        "tatínek",
        "taxík",
        "téci",
        "teď",
        "teda",
        "tedy",
        "tehdejší",
        "tehdy",
        "těhotenství",
        "těhotný",
        "technický",
        "technika",
        "technologický",
        "technologie",
        "tekutina",
        "telefon",
        "telefonní",
        "tělesný",
        "těleso",
        "televize",
        "televizní",
        "televizor",
        "tělo",
        "téma",
        "téměř",
        "temnota",
        "temný",
        "tempo",
        "ten",
        "tendence",
        "tenhle",
        "tenkrát",
        "tenký",
        "tento",
        "tentokrát",
        "tentýž",
        "teoretický",
        "teorie",
        "tepelný",
        "Teplice",
        "teplo",
        "teplota",
        "teplý",
        "teprve",
        "terapie",
        "terasa",
        "terén",
        "termín",
        "těsně",
        "těsný",
        "test",
        "těsto",
        "těšit",
        "teta",
        "text",
        "též",
        "těžba",
        "těžce",
        "těžit",
        "těžko",
        "těžký",
        "the",
        "ticho",
        "tichý",
        "tip",
        "tisíc",
        "tisk",
        "tiskárna",
        "tisknout",
        "tiskový",
        "tiše",
        "titul",
        "tj",
        "tkáň",
        "tlačit",
        "tlačítko",
        "tlak",
        "tloušťka",
        "tlustý",
        "tma",
        "tmavý",
        "to",
        "točit",
        "tok",
        "tolik",
        "Tomáš",
        "tón",
        "top",
        "totiž",
        "touha",
        "toužit",
        "továrna",
        "tradice",
        "tradičně",
        "tradiční",
        "tragedie",
        "tragický",
        "tramvaj",
        "trápit",
        "trasa",
        "trať",
        "tráva",
        "trávit",
        "trávník",
        "trefit",
        "trend",
        "trenér",
        "trénink",
        "trénovat",
        "trest",
        "trestní",
        "trestný",
        "trh",
        "tričko",
        "trik",
        "triumf",
        "trocha",
        "trochu",
        "trojice",
        "trošku",
        "trouba",
        "trpělivě",
        "trpělivost",
        "trpět",
        "trubka",
        "trvale",
        "trvalý",
        "trvat",
        "tržba",
        "třást",
        "třeba",
        "třebaže",
        "třetí",
        "třetina",
        "tři",
        "třicet",
        "třída",
        "třikrát",
        "třináct",
        "tu",
        "tudíž",
        "tuhý",
        "tuk",
        "tuna",
        "tunel",
        "Turecko",
        "turecký",
        "turista",
        "turistický",
        "turnaj",
        "tušení",
        "tušit",
        "tuzemský",
        "tužka",
        "TV",
        "tvar",
        "tvář",
        "tvářit",
        "tvor",
        "tvorba",
        "tvořit",
        "tvrdě",
        "tvrdit",
        "tvrdý",
        "tvrzení",
        "tvůj",
        "tvůrce",
        "tvůrčí",
        "ty",
        "tyč",
        "týden",
        "týdně",
        "týkající",
        "týkat",
        "tým",
        "typ",
        "typický",
        "týž",
        "tzv",
        "u",
        "ublížit",
        "ubohý",
        "ucítit",
        "úcta",
        "účast",
        "účastník",
        "účastnit",
        "učebnice",
        "účel",
        "učení",
        "účet",
        "účinek",
        "učinit",
        "účinnost",
        "účinný",
        "učit",
        "učitel",
        "učitelka",
        "údaj",
        "údajně",
        "událost",
        "udělat",
        "udělit",
        "úder",
        "udeřit",
        "údolí",
        "údržba",
        "udržet",
        "udržovat",
        "úhel",
        "uherský",
        "uhlí",
        "uchazeč",
        "ucho",
        "uchopit",
        "ujistit",
        "ujít",
        "ujmout",
        "ukázat",
        "ukazatel",
        "ukázka",
        "ukazovat",
        "ukládat",
        "uklidnit",
        "úkol",
        "úkon",
        "ukončení",
        "ukončit",
        "Ukrajina",
        "ukrást",
        "úleva",
        "ulevit",
        "ulice",
        "ulička",
        "úloha",
        "uložený",
        "uložit",
        "umělec",
        "umělecký",
        "umělý",
        "umění",
        "umět",
        "umírat",
        "umístění",
        "umístěný",
        "umístit",
        "umožnit",
        "umožňovat",
        "úmrtí",
        "umřít",
        "úmysl",
        "únava",
        "unavený",
        "unést",
        "unie",
        "uniforma",
        "únik",
        "unikátní",
        "uniknout",
        "univerzální",
        "univerzita",
        "únor",
        "upadnout",
        "uplatnění",
        "uplatnit",
        "uplatňovat",
        "úplně",
        "úplný",
        "uplynout",
        "uplynulý",
        "upozornit",
        "upozorňovat",
        "úprava",
        "upravený",
        "upravit",
        "upravovat",
        "uprostřed",
        "upřímně",
        "upřímný",
        "úraz",
        "urazit",
        "určení",
        "určený",
        "určit",
        "určitě",
        "určitý",
        "určovat",
        "úroveň",
        "úřad",
        "úřední",
        "úředník",
        "USA",
        "usadit",
        "USB",
        "úsek",
        "úsilí",
        "usilovat",
        "uskutečnit",
        "uslyšet",
        "usmát",
        "úsměv",
        "usmívat",
        "usnout",
        "usoudit",
        "úspěch",
        "úspěšně",
        "úspěšný",
        "uspět",
        "úspora",
        "úsporný",
        "uspořádání",
        "uspořádat",
        "ústa",
        "ustanovení",
        "ústav",
        "ústavní",
        "ústecký",
        "Ústí",
        "ustoupit",
        "ústřední",
        "ušetřit",
        "utéci",
        "útěk",
        "úterý",
        "utíkat",
        "utkání",
        "útočník",
        "útok",
        "utrpení",
        "utrpět",
        "útvar",
        "uvádět",
        "úvaha",
        "uvařit",
        "uvažovat",
        "uvedený",
        "uvědomit",
        "uvědomovat",
        "úvěr",
        "uvěřit",
        "uvěřitelně",
        "uvést",
        "uvidět",
        "uvnitř",
        "úvod",
        "úvodní",
        "uvolněný",
        "uvolnit",
        "uzavírat",
        "uzavřený",
        "uzavřít",
        "uzel",
        "území",
        "územní",
        "úzkost",
        "úzký",
        "uznání",
        "uznat",
        "uznávat",
        "už",
        "úžasný",
        "užít",
        "užitečný",
        "užívání",
        "užívat",
        "uživatel",
        "v",
        "vada",
        "vadit",
        "váha",
        "váhat",
        "vajíčko",
        "valašský",
        "válečný",
        "válka",
        "valný",
        "van",
        "vana",
        "Vánoce",
        "vánoční",
        "varianta",
        "varování",
        "varovat",
        "Vary",
        "vaření",
        "vařit",
        "váš",
        "vášeň",
        "vázat",
        "vazba",
        "vážený",
        "vážit",
        "vážně",
        "vážný",
        "vcelku",
        "včas",
        "včela",
        "včera",
        "včerejší",
        "včetně",
        "vděčný",
        "věc",
        "večer",
        "večerní",
        "večeře",
        "večírek",
        "věčně",
        "věčný",
        "věda",
        "vědec",
        "vědecký",
        "vedení",
        "vedený",
        "vědět",
        "vedle",
        "vedlejší",
        "vědomí",
        "vědomý",
        "vedoucí",
        "vejce",
        "vejít",
        "věk",
        "věkový",
        "vektor",
        "veletrh",
        "velice",
        "veličina",
        "velikost",
        "veliký",
        "velitel",
        "velký",
        "velmi",
        "ven",
        "venkov",
        "venkovní",
        "venkovský",
        "venku",
        "věnovat",
        "věrný",
        "verš",
        "verze",
        "veřejně",
        "veřejnost",
        "veřejný",
        "věřící",
        "věřit",
        "ves",
        "veselý",
        "vesmír",
        "vesnice",
        "vést",
        "veškerý",
        "věta",
        "větev",
        "větrný",
        "většina",
        "většinou",
        "vězeň",
        "vězení",
        "věznice",
        "vézt",
        "věž",
        "vhodný",
        "vchod",
        "víc",
        "více",
        "víceméně",
        "víčko",
        "vídat",
        "Vídeň",
        "vidění",
        "video",
        "vidět",
        "viditelný",
        "víkend",
        "vila",
        "vina",
        "vinný",
        "víno",
        "vir",
        "víra",
        "virtuální",
        "viset",
        "vitamín",
        "vítat",
        "vítěz",
        "vítězný",
        "vítězství",
        "vítr",
        "viz",
        "vize",
        "vláda",
        "vládní",
        "vládnout",
        "vlak",
        "vlákno",
        "vlas",
        "vlast",
        "vlastně",
        "vlastní",
        "vlastnictví",
        "vlastník",
        "vlastnit",
        "vlastnost",
        "vlevo",
        "vlhkost",
        "vlhký",
        "vliv",
        "vlk",
        "vlna",
        "vloni",
        "vložit",
        "Vltava",
        "vnější",
        "vnímání",
        "vnímat",
        "vnitro",
        "vnitřní",
        "voda",
        "vodní",
        "voják",
        "vojenský",
        "vojsko",
        "volání",
        "volant",
        "volat",
        "volba",
        "volby",
        "volební",
        "volič",
        "volit",
        "volně",
        "volno",
        "volný",
        "von",
        "vonět",
        "vozidlo",
        "vozík",
        "vozit",
        "vpravo",
        "vpřed",
        "vracet",
        "vrah",
        "vrata",
        "vrátit",
        "vrazit",
        "vražda",
        "vrhat",
        "vrhnout",
        "vrch",
        "vrchní",
        "vrchol",
        "vrstva",
        "vsadit",
        "vstát",
        "vstávat",
        "vstoupit",
        "vstříc",
        "vstup",
        "vstupenka",
        "vstupní",
        "vstupovat",
        "však",
        "všecek",
        "všední",
        "všechen",
        "všeobecně",
        "všeobecný",
        "všímat",
        "všimnout",
        "všude",
        "vteřina",
        "vtip",
        "vtipný",
        "vtom",
        "vůbec",
        "vůči",
        "vůdce",
        "vůle",
        "vůně",
        "vůz",
        "vy",
        "výbava",
        "vybavení",
        "vybavený",
        "vybavit",
        "vyběhnout",
        "výběr",
        "výběrový",
        "vybírat",
        "výbor",
        "výborně",
        "výborný",
        "vybraný",
        "vybrat",
        "vybudovat",
        "výbuch",
        "výcvik",
        "vyčítat",
        "výdaj",
        "vydání",
        "vydaný",
        "vydat",
        "vydávat",
        "vydechnout",
        "vydělat",
        "vydělávat",
        "vyděsit",
        "vydržet",
        "vyhlásit",
        "vyhláška",
        "výhled",
        "vyhledat",
        "vyhledávat",
        "vyhlídka",
        "vyhnat",
        "vyhnout",
        "výhoda",
        "vyhodit",
        "výhodný",
        "vyhovět",
        "vyhovovat",
        "výhra",
        "výhradně",
        "vyhrát",
        "vyhrknout",
        "vyhýbat",
        "vycházet",
        "východ",
        "východní",
        "výchova",
        "výchozí",
        "vyjádření",
        "vyjádřit",
        "vyjadřovat",
        "vyjet",
        "výjimečně",
        "výjimečný",
        "výjimka",
        "vyjít",
        "vykazovat",
        "výklad",
        "vykládat",
        "výkon",
        "vykonávat",
        "výkonný",
        "vykročit",
        "výkřik",
        "vykřiknout",
        "výlet",
        "vylézt",
        "vyloučit",
        "výměna",
        "vyměnit",
        "vymyslet",
        "vymýšlet",
        "vyndat",
        "vynechat",
        "vynést",
        "vynikající",
        "vynořit",
        "výnos",
        "vypadat",
        "vypadnout",
        "vypít",
        "vyplatit",
        "vyplnit",
        "vyplývat",
        "vypnout",
        "výpočet",
        "výpověď",
        "vypovídat",
        "vypracovat",
        "výprava",
        "vyprávění",
        "vyprávět",
        "vypravit",
        "vypustit",
        "vyrábět",
        "výraz",
        "vyrazit",
        "výrazně",
        "výrazný",
        "výroba",
        "výrobce",
        "výrobek",
        "vyrobený",
        "vyrobit",
        "výrobní",
        "výročí",
        "výrok",
        "vyrovnaný",
        "vyrovnat",
        "vyrůst",
        "vyrůstat",
        "vyřešit",
        "vyřídit",
        "vysílání",
        "vysílat",
        "vyskočit",
        "výskyt",
        "vyskytovat",
        "vyslat",
        "výsledek",
        "výsledný",
        "výslech",
        "vyslechnout",
        "vyslovit",
        "vysoce",
        "vysočina",
        "vysoko",
        "vysoký",
        "vyspělý",
        "výstava",
        "výstavba",
        "vystavit",
        "vystavovat",
        "vystoupení",
        "vystoupit",
        "vystřelit",
        "vystřídat",
        "vystudovat",
        "výstup",
        "výstupní",
        "vystupovat",
        "vysvětlení",
        "vysvětlit",
        "vysvětlovat",
        "výše",
        "vyšetření",
        "vyšetřování",
        "vyšetřovatel",
        "výška",
        "výtah",
        "vytáhnout",
        "vytápění",
        "vytrhnout",
        "výtvarný",
        "vytváření",
        "vytvářet",
        "vytvoření",
        "vytvořený",
        "vytvořit",
        "výuka",
        "využít",
        "využití",
        "využívání",
        "využívat",
        "vyvést",
        "vyvíjet",
        "vyvinout",
        "vývoj",
        "vývojový",
        "vyvolat",
        "vyvolávat",
        "vyzkoušet",
        "výzkum",
        "výzkumný",
        "vyznačovat",
        "význam",
        "významně",
        "významný",
        "vyznat",
        "výzva",
        "vyzvat",
        "vyzvednout",
        "vyžádat",
        "vyžadovat",
        "výživa",
        "vzácný",
        "vzadu",
        "vzájemně",
        "vzájemný",
        "vzápětí",
        "vzbudit",
        "vzdálenost",
        "vzdálený",
        "vzdát",
        "vzdělání",
        "vzdělaný",
        "vzdělávací",
        "vzdělávání",
        "vzduch",
        "vzhled",
        "vzhledem",
        "vzhlédnout",
        "vzhůru",
        "vzít",
        "vzkaz",
        "vznášet",
        "vznik",
        "vznikat",
        "vzniklý",
        "vzniknout",
        "vzor",
        "vzorec",
        "vzorek",
        "vzpamatovat",
        "vzpomenout",
        "vzpomínat",
        "vzpomínka",
        "vzrůst",
        "vzrušení",
        "vztah",
        "vztahovat",
        "vztek",
        "vždy",
        "vždycky",
        "vždyť",
        "Washington",
        "Web",
        "webový",
        "Windows",
        "York",
        "z",
        "za",
        "zabalit",
        "zábava",
        "zábavný",
        "záběr",
        "zabezpečení",
        "zabíjet",
        "zabírat",
        "zabít",
        "zábradlí",
        "zabránit",
        "zabrat",
        "zabývat",
        "začátek",
        "začínat",
        "začít",
        "záda",
        "zadat",
        "zadek",
        "zadívat",
        "zadní",
        "zadržet",
        "záhada",
        "zahájení",
        "zahájit",
        "zahlédnout",
        "zahrada",
        "zahrádka",
        "zahradní",
        "zahraničí",
        "zahraniční",
        "zahrát",
        "zahrnout",
        "zahrnovat",
        "záhy",
        "zahynout",
        "zacházet",
        "záchod",
        "zachování",
        "zachovat",
        "záchrana",
        "zachránit",
        "záchranný",
        "záchvat",
        "zachytit",
        "zájem",
        "zájemce",
        "zajet",
        "zajímat",
        "zajímavost",
        "zajímavý",
        "zajistit",
        "zajištění",
        "zajišťovat",
        "zajít",
        "zákaz",
        "zakázat",
        "zakázka",
        "zákazník",
        "základ",
        "zakládat",
        "zakladatel",
        "základna",
        "základní",
        "zákon",
        "zákoník",
        "zákonný",
        "zákrok",
        "zakrýt",
        "záležet",
        "záležitost",
        "zalít",
        "záloha",
        "založení",
        "založený",
        "založit",
        "zámek",
        "záměr",
        "zaměření",
        "zaměřený",
        "zaměřit",
        "zaměřovat",
        "zaměstnanec",
        "zaměstnání",
        "zaměstnavatel",
        "zamilovaný",
        "zamilovat",
        "zamířit",
        "zamumlat",
        "zamyslet",
        "zanechat",
        "zánět",
        "západ",
        "západní",
        "zapadnout",
        "zapálit",
        "zápas",
        "zápěstí",
        "zápis",
        "zaplatit",
        "zapnout",
        "zapojení",
        "zapojit",
        "zapomenout",
        "zapomínat",
        "zapotřebí",
        "zapsat",
        "zarazit",
        "zároveň",
        "záruka",
        "zařadit",
        "záření",
        "září",
        "zařídit",
        "zářit",
        "zařízení",
        "zas",
        "zásada",
        "zásadně",
        "zásadní",
        "zásah",
        "zasáhnout",
        "zasahovat",
        "zase",
        "zasedání",
        "zaskočit",
        "zaslechnout",
        "zasloužit",
        "zásluha",
        "zasmát",
        "zásoba",
        "zastávat",
        "zastavit",
        "zastávka",
        "zastoupení",
        "zastřelit",
        "zástupce",
        "zastupitel",
        "zastupitelstvo",
        "zásuvka",
        "zašeptat",
        "zatáčka",
        "zátěž",
        "zatím",
        "zatímco",
        "zatížení",
        "zatknout",
        "zato",
        "zaujmout",
        "zaútočit",
        "závazek",
        "závažný",
        "zavedení",
        "závěr",
        "závěrečný",
        "závěs",
        "zavěsit",
        "zavést",
        "zavírat",
        "záviset",
        "závislost",
        "závislý",
        "závod",
        "závodník",
        "zavolat",
        "zavrtět",
        "zavřený",
        "zavřít",
        "zázemí",
        "záznam",
        "zaznamenat",
        "zaznít",
        "zázrak",
        "zazvonit",
        "zažít",
        "zážitek",
        "zažívat",
        "zbavit",
        "zboží",
        "zbraň",
        "zbylý",
        "zbýt",
        "zbytečně",
        "zbytečný",
        "zbytek",
        "zbývající",
        "zbývat",
        "zcela",
        "zčásti",
        "zda",
        "zdaleka",
        "zdánlivě",
        "zdarma",
        "zdát",
        "zde",
        "zdejší",
        "Zdeněk",
        "zdobit",
        "zdraví",
        "zdravotní",
        "zdravotnický",
        "zdravotnictví",
        "zdravý",
        "zdroj",
        "zdůraznit",
        "zdůrazňovat",
        "zeď",
        "zejména",
        "zeleň",
        "zelenina",
        "zelený",
        "Zeman",
        "země",
        "zemědělec",
        "zemědělský",
        "zemědělství",
        "zemní",
        "zemřít",
        "zemský",
        "zeptat",
        "zesilovač",
        "zhluboka",
        "zhroutit",
        "zhruba",
        "zima",
        "zimní",
        "zírat",
        "zisk",
        "získání",
        "získaný",
        "získat",
        "získávat",
        "zítra",
        "zjevně",
        "zjistit",
        "zjištění",
        "zjišťovat",
        "zklamání",
        "zklamat",
        "zkontrolovat",
        "zkoumání",
        "zkoumat",
        "zkoušet",
        "zkouška",
        "zkratka",
        "zkrátka",
        "zkusit",
        "zkušenost",
        "zkušený",
        "zlato",
        "zlatý",
        "zlepšení",
        "zlepšit",
        "zlepšovat",
        "Zlín",
        "zlínský",
        "zlo",
        "zlobit",
        "zločin",
        "zloděj",
        "zlomit",
        "zlý",
        "zmatek",
        "zmatený",
        "změna",
        "změnit",
        "zmíněný",
        "zmínit",
        "zmínka",
        "zmiňovat",
        "zmizet",
        "zmocnit",
        "značka",
        "značně",
        "značný",
        "znak",
        "znalec",
        "znalost",
        "znamenat",
        "znamení",
        "známka",
        "známý",
        "znát",
        "zničit",
        "znít",
        "znova",
        "znovu",
        "zobrazení",
        "zobrazit",
        "zodpovědnost",
        "zodpovědný",
        "zóna",
        "ZOO",
        "zopakovat",
        "zoufale",
        "zoufalství",
        "zoufalý",
        "zpátky",
        "zpět",
        "zpětný",
        "zpěv",
        "zpěvačka",
        "zpěvák",
        "zpívat",
        "zpočátku",
        "zpomalit",
        "zpracování",
        "zpracovat",
        "zpracovávat",
        "zpráva",
        "zpravidla",
        "způsob",
        "způsobený",
        "způsobit",
        "způsobovat",
        "zrak",
        "zralý",
        "zranění",
        "zraněný",
        "zranit",
        "zrcadlo",
        "zrodit",
        "zrovna",
        "zrušení",
        "zrušit",
        "zřejmě",
        "zřejmý",
        "zřetelně",
        "zřetelný",
        "zřídit",
        "zřídka",
        "ztracený",
        "ztrácet",
        "ztráta",
        "ztratit",
        "zub",
        "zúčastnit",
        "zůstat",
        "zůstávat",
        "Zuzana",
        "zvaný",
        "zvát",
        "zvažovat",
        "zvedat",
        "zvědavý",
        "zvednout",
        "zveřejnit",
        "zvíře",
        "zvítězit",
        "zvládat",
        "zvládnout",
        "zvlášť",
        "zvláště",
        "zvláštní",
        "zvolat",
        "zvolený",
        "zvolit",
        "zvolna",
        "zvuk",
        "zvukový",
        "zvyk",
        "zvyklý",
        "zvyknout",
        "zvýšení",
        "zvýšený",
        "zvýšit",
        "zvyšovat",
        "žádat",
        "žádný",
        "žádost",
        "žádoucí",
        "žák",
        "žaloba",
        "žaludek",
        "žánr",
        "že",
        "žebříček",
        "železnice",
        "železniční",
        "železný",
        "železo",
        "žena",
        "ženská",
        "ženský",
        "Žid",
        "žid",
        "židle",
        "židovský",
        "žijící",
        "žíla",
        "žít",
        "živit",
        "živočich",
        "živočišný",
        "život",
        "životní",
        "životnost",
        "živý",
        "žlutý",
    )

    parts_of_speech: Dict[str, tuple] = {}
